Install Davra Platform on-prem with Debian 10
=============================================

1. Get a clean, default installation of your distro
2. Ensure you have a fixed IP address and minimum requirements are met
3. Check the rest of the notes below before starting
4. Run `install.sh` as normal.

# Base Installation

This assumes a clean base installation.

Minimum Requirements: You'll need at least 8 cores, 32GB Ram and 100GB of free disk space.
NOTE: this refers to free space on the home partition. The debian installers default partitioning will reserve some space for swap & temp files, and on the remaining home partition some space will obviously be used by system files and installed software. If using virtualisation, be sure to allow for all this and start with 100GB vdisk.
After installing, run `df . -H` to confirm.

Recommended Requirements: 8 cores, 64GB ram and 1TB disk - for all deployments to successfully get the resources they're claiming. (You can over-provision, but that will likely lead to issues later)

If installing on VirtualBox/Bare Metal/Esxi, see the relevent notes below before starting.

If installing from the debian iso installer, use the usual defaults, except in the optional extra packages:
* Don't bother with a desktop environment or print server.
* You will want the SSH server though, as it's best to ssh in (using terminal of choice, or VSCode similar to [Cloud-hosted development environment](https://davranetworks.atlassian.net/wiki/spaces/IARCH/pages/724434952/Cloud-hosted+development+environment) for consistency...)


## Debian Initial Setup:

You may need to install `sudo` and add yourself to the sudo group.
(AWS instances do not need this)
```
su
apt install -y sudo
sudo adduser $USER sudo
```

While you're there and still su, you'll should also get net-tools (ifconfig & route) and the usual build essentials, also add sbin to your path:
```
apt update
apt install -y net-tools curl git build-essential dkms linux-headers-$(uname -r)
echo "export PATH=/sbin/:$PATH" >> /root/.bashrc
echo "export PATH=/sbin/:$PATH" >> /home/$USER/.bashrc
```

## Fixed IP

As with any Kubernetes installation, you'll need to have a consistent, fixed IP address.

Run `sudo cat /etc/network/interfaces` and if you see something like: `iface *ensNN* inet **dhcp**` then you will need to take some action.

1. If possible, the simplest option is to set the current IP config as static route on the router. This would leave everything as configured, and reserve the assigned IP address for this machine, thus keeping it consistent. 
2. If that is not possible, then we need to configure a static IP manually.
   - Run `ifconfig *ensNN*` for whatever interface name is current listed as dhcp in the /etc/network/interfaces file.
   - Get the inet, netmask, broadcast details
   - Run `sudo nano /etc/network/interfaces`
   - And edit the file to add the static details:
   - Run `sudo cat /etc/network/interfaces`
   - Change `iface ... **dhcp**` to be `iface ... static` and immediately after, add the address, netmask & gateway details.
   - Result should look something like:
      ```
      ...
      iface eth0 inet static
         address 192.168.1.110
         broadcast 192.168.1.255
         netmask 255.255.255.0
         gateway 192.168.1.1
         dns-nameservers 8.8.8.8
      ```
   - ensure your dns servers are also set, that resolve conf contains a valid dns server address and external names can be resolved
   - Also check /etc/resolve.conf and sure your `dns-nameservers` match the name servers listed. 


## Swap Mem:

You may need to disable swap space. (AWS instances do not need this)

k8s doesn't like swap space, this can be temporarily disabled with `swapoff -a` but edit `/etc/fstab` and comment out the 'swap' entry to get this done properly and permanent
It should end up looking something like:
```
# swap was on /dev/sda5 during installation
# UUID=9cf11cb3-fa91-4e07-bd01-6825d69204cc none  swap  sw   0   0
```

# If **any** of the above system changes are made, reboot before the install.

## VirtualBox

If using VirtualBox:
 - Select **Bridge Network Connection**
 - On windows: disable Hyper-V & WSL
 - Don't use VirtualBox 6.1 - this somehow causes problems with Hash Sum Mismatches
 - Use [VirtualBox 6.0.24](https://www.virtualbox.org/wiki/Download_Old_Builds_6_0)


You probably want to mount a shared folder (after installing core/build extras above):
```
sudo mkdir -p /media/cdrom
sudo mount /dev/cdrom /media/cdrom
sudo /media/cdrom/VBoxLinuxAdditions.run
sudo adduser $USER vboxsf
```


> OPTIONAL TEST: Test Net connection:

Check IP with ifconfig, then run: `sudo python3 -m http.server 80`

Then from host machine, browse to the VBox IP to test basic webserver/firewall/net settings are all OK.

Any issues with this, you should probably sort out now - it's only going to get worse...

VBox seems to just hang sometimes especially on restarts, just hit return and wait a sec, still nothing? then you'll just need to 'Machine > Reset'



## Bare Metal

TBA


## Esxi

TBA


-------------------------------------


# Install

## Non-interactive Mode

If run via Jenkins, or with output piped to a logfile, the installation will continue as before.

If any critcal errors are found in the pre-install checklist, the installation will exit early a log the reason why.

Otherwise, wait for the script completion, then inspect the logs as normal.

This mode assumes that the user knows what they're doing and has met all requirements.

## Interactive Mode

If the user run s`sudo ./install.sh` with the standard output as the terminal, then the Interactive mode will kick in and inform the user of the preinstallation checks, allowing them to review & exit before continuing.

> NOTE: this is only intended to help new users running an installation for the first time. Once the user is more au fait with the installation process & target machines, then they are likely to fire-and-forget with the non-interactive option.

This pre-install script will check the system state and will exit if errors are found.
Double check the outputs & the prerequisites above to continue.
There may be warnings detected and reported, these may be ignored and you can continue the install regardless withe caveat that those warnings may cause ssues later.

Log files for the main sections will be generated in `localhost/logs/`

## Troubleshooting

* Installation should take about 45 minutes, but allow up to an hour in case of network slowness, kubernetes time to respond, etc...
* During the installation process, there are quite a few 'Waiting For <something>...' pauses, and some of these do take a while and may appear to be unresponsive, but be patient and wait for the installer to continue or return a timeout message. (The installation wont just hang - eventually there will be a response.)
* If there are any issues and the installation does not complete successfully, the script can be re-run and will remove & reset any previous installation attempt. 
* The log files for the main sections will be generated in `localhost/logs/`. Zip that entire directory and send to your local Davra platform engineer to inspect and advise.
