apiVersion: apps/v1
kind: Deployment
metadata:
  labels:
    name: davra-api-lwm2m
  name: davra-api-lwm2m
spec:
  replicas: 1
  selector:
    matchLabels:
      name: davra-api-lwm2m
  template:
    metadata:
      labels:
        name: davra-api-lwm2m
    spec:
      serviceAccountName: davra-api-serviceaccount
      containers:
        - args:
          - --abort-on-uncaught-exception
          - --unhandled-rejections=strict
          - --max-old-space-size=2560
          - index.js
          command:
          - node
          image: docker.io/davradocker/davra-api:DAVRA_API_VERSION
          securityContext:
            privileged: true
          name: davra-api-lwm2m
          ports:
            - name: davra-api-lwm2m
              containerPort: 8080
          resources:
            requests:
              memory: 512Mi
              cpu: 1000m
          readinessProbe:
            httpGet:
              path: /health
              port: 8080
            initialDelaySeconds: 30
            periodSeconds: 5
          volumeMounts:
            - name: jenkins-secret
              mountPath: /etc/jenkins
            - name: kafka-client-tls-assets
              mountPath: /etc/kafka-client-tls-assets
            - name: davra-api-token
              mountPath: /etc/davra-api-token
            - name: ui-hosts
              mountPath: /etc/davra-ui
            - name: microservice-workspaces
              mountPath: /microservice-workspaces
            - name: mongodb-connection-string
              mountPath: /etc/mongodb-connection-string
            - mountPath: /etc/davra/lwm2m-aes-key
              name: lwm2m-aes-key
      volumes:
        - name: jenkins-secret
          secret:
            secretName: jenkins
        - name: kafka-client-tls-assets
          secret:
            secretName: kafka-client-tls-assets
        - name: davra-api-token
          secret:
            secretName: davra-api-token
        - name: ui-hosts
          configMap:
            name: ui-hosts
            items:
              - key: uiHosts.json
                path: uiHosts.json
        - name: microservice-workspaces
          persistentVolumeClaim:
            claimName: microservice-workspaces-pvc
        - name: mongodb-connection-string
          secret:
            secretName: mongodb-connection-string
        - name: lwm2m-aes-key
          secret:
            secretName: lwm2m-aes-key
