#!/bin/bash

cd `dirname $0`

source ./utils.sh

TIMEOUT_IN_MINUTES=5
TIMEOUT_IN_SECONDS=`expr $TIMEOUT_IN_MINUTES \* 60`
SLEEP_SECONDS=3
TIMEOUT_IN_LOOPS=`expr $TIMEOUT_IN_SECONDS / $SLEEP_SECONDS`
NOT_TIMEOUT=`expr $TIMEOUT_IN_LOOPS + 100`
REPEATEDLY_UP=10

doDeployment cassandra
doService cassandra

doDeployment kairosdb
doService kairosdb

doDeployment zookeeper default true
doService zookeeper

#
# Calls an endpoint over and over until a positive response is reached
# $1 the url to hit
# $2 the Bearer token to use
#
function waitOnZookeeper {

    echo "Waiting on zookeeper"

    PASS_THRESHOLD=10
    cnt=0
	pass_cnt=0
    while [ $cnt -lt $TIMEOUT_IN_LOOPS ]
    do
        kubectl get deployment zookeeper -o yaml | grep 'readyReplicas: 1' > /dev/null
        if [ $? -eq 0 ] ; then
            pass_cnt=`expr $pass_cnt + 1`
            if [ $pass_cnt -ge $PASS_THRESHOLD ] ; then
	            cnt=`expr $NOT_TIMEOUT - 1`
	        fi
	    else
	        #echo "Resetting pass counter to zero"
	        pass_cnt=0
	        printf "!"
	    fi
        sleep 3
        printf "-"
        cnt=`expr $cnt + 1`
    done

    if [ $cnt -ne $NOT_TIMEOUT ] ; then
        echo "TIMEOUT! Endpoint $1 has not come up"
        exit 1
    fi

}

waitOnZookeeper

kafka/deploy-config.sh
kafka/deploy-kafka-secrets.sh
NEW_CERTS=$?
kubectl get pod -n default | grep kafka | grep -v kafka-offset-monitor | grep -v davra-api-kafka
if [ $? -eq 0 -a $NEW_CERTS -eq 0 ] ; then
    echo "New certs applied and kafka is running, bouncing kafka"
    kubectl get pod -n default | grep kafka | grep -v kafka-offset-monitor | grep -v davra-api-kafka | awk '{system("kubectl delete pod "$1)}'
fi
doDeployment kafka default true
doService kafka default true

doDeployment postgres
doService postgres

doDeployment mongodb
doService mongodb

# Check if there is already a MongoDB secret
kubectl get secret mongodb-connection-string > /dev/null 2>&1
if [ $? -ne 0 ] ; then
    echo "Creating mongodb-connection-string secret"

    # If there is a MONGO_URI environmental variable, then check if the URI is working
    if [ ! -z "$MONGO_URI" ]; then
        # We will use the mongo shell from within the cluster, so ensure that the container is running
        echo "There is MONGO_URI env, testing the given endpoint. This will stop the installer if check fails."
        waitOnMongo
        checkMongoURI $MONGO_URI
    fi

    # If no MONGO_URI is defined, then default back to cluster MongoDB
    MONGO_URI=${MONGO_URI:-mongodb://mongodb.default:27017}
    MONGO_URI=$(echo -n "$MONGO_URI" | base64 -w 0)
    sed s/MONGO_URI/$MONGO_URI/g mongodb-connection-secret.yaml.tpl > mongodb-connection-secret.yaml
    doSecret mongodb-connection
    echo "Created mongodb-connection-string secret."
else
    echo "mongodb-connection-string secret already exists, moving on."
fi

doDeployment redis
doService redis

doDeployment restheart
doService restheart
waitOnDeployment restheart
RESTHEART_POD=`kubectl get pod -n default | grep restheart | awk '{print $1}'`
waitOnPod $RESTHEART_POD

doIngress connecthing

chmod 777 localhost/mqtt/mqtt-deploy-secrets.sh
localhost/mqtt/mqtt-deploy-secrets.sh
doDeployment davra-mqtt
doService davra-mqtt
