#!/bin/bash


KAFKA_REPLICATION_FACTOR=${KAFKA_REPLICATION_FACTOR:-1}

#create topics
echo "Creating KAFKA Topics for all..."
cnt=0
while [ $cnt -lt 600 ]
do
  kubectl get pod -l name=kafka | grep kafka | grep -v kafka-offset | grep -v davra-api-kafka | grep -i Running | grep 1/1
  if [ $? -eq 0 ] ; then
      cnt=`expr 700`
  fi
  printf "#"
  sleep 3
  cnt=`expr $cnt + 1`
done

if [ $cnt -ne 701 ] ; then
  echo "TIMEOUT! kafka not available"
  exit 1
fi

echo "Kafka up"
echo ""
KAFKA_POD=`kubectl get pod -l name=kafka | grep kafka | grep -v kafka-offset | grep -v davra-api-kafka | grep -i Running | awk '{print $1}' | head -1`
echo "Kafka pod: $KAFKA_POD"

if [ -z $KAFKA_POD ] ; then
  echo "Kafka not available"
  exit 1
fi

cnt=0
while [ $cnt -lt 600 ]
do
  kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/zookeeper-shell.sh zookeeper.default:2181 <<< 'ls /brokers/ids' | grep ^\\\\[ | grep -v \\\\[\\\\]"
  if [ $? -eq 0 ] ; then
      cnt=`expr 700`
  fi
  printf "#"
  sleep 1
  cnt=`expr $cnt + 1`
done

if [ $cnt -ne 701 ] ; then
  echo "TIMEOUT! zookeeper not available"
  exit 1
fi

kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --list --bootstrap-server localhost:9091" | grep all.devices
if [ $? -ne 0 ] ; then
  kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --bootstrap-server localhost:9091 --create --partitions 1 --replication-factor="$KAFKA_REPLICATION_FACTOR" --topic all.devices"
  kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --bootstrap-server localhost:9091 --create --partitions 1 --replication-factor="$KAFKA_REPLICATION_FACTOR" --topic all.ruban-iotdata"
  kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --bootstrap-server localhost:9091 --create --partitions 1 --replication-factor="$KAFKA_REPLICATION_FACTOR" --topic all.davra-logs"
  kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --bootstrap-server localhost:9091 --create --partitions 1 --replication-factor="$KAFKA_REPLICATION_FACTOR" --topic all.davra-auditLogs"
  kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --bootstrap-server localhost:9091 --create --partitions 1 --replication-factor="$KAFKA_REPLICATION_FACTOR" --topic ruban.devices"
  kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --bootstrap-server localhost:9091 --create --partitions 1 --replication-factor="$KAFKA_REPLICATION_FACTOR" --topic ruban.ruban-iotdata"
  kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --bootstrap-server localhost:9091 --create --partitions 1 --replication-factor="$KAFKA_REPLICATION_FACTOR" --topic ruban.davra-logs"
fi

kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --list --bootstrap-server localhost:9091" | grep ruban.iotdata-preprocessor
if [ $? -ne 0 ] ; then
  kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --bootstrap-server localhost:9091 --create --partitions 1 --replication-factor="$KAFKA_REPLICATION_FACTOR" --topic ruban.iotdata-preprocessor"
fi

if [ ! -f .kafka-retention-policy-22062017 ] ; then
  echo "Setting retention time for kafka topics"
  kubectl exec -i $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh --bootstrap-server=localhost:9091 --entity-name=all.devices                  --entity-type=topics --alter --add-config retention.ms=43200000,delete.retention.ms=43200001,cleanup.policy=delete,segment.bytes=104857600"
  kubectl exec -i $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh --bootstrap-server=localhost:9091 --entity-name=all.ruban-iotdata            --entity-type=topics --alter --add-config retention.ms=43200000,delete.retention.ms=43200001,cleanup.policy=delete,segment.bytes=104857600"
  kubectl exec -i $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh --bootstrap-server=localhost:9091 --entity-name=all.davra-logs               --entity-type=topics --alter --add-config retention.ms=43200000,delete.retention.ms=43200001,cleanup.policy=delete,segment.bytes=104857600"
  kubectl exec -i $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh --bootstrap-server=localhost:9091 --entity-name=all.davra-auditLogs          --entity-type=topics --alter --add-config retention.ms=43200000,delete.retention.ms=43200001,cleanup.policy=delete,segment.bytes=104857600"
  kubectl exec -i $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh --bootstrap-server=localhost:9091 --entity-name=ruban.devices                --entity-type=topics --alter --add-config retention.ms=43200000,delete.retention.ms=43200001,cleanup.policy=delete,segment.bytes=104857600"
  kubectl exec -i $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh --bootstrap-server=localhost:9091 --entity-name=ruban.ruban-iotdata          --entity-type=topics --alter --add-config retention.ms=43200000,delete.retention.ms=43200001,cleanup.policy=delete,segment.bytes=104857600"
  kubectl exec -i $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh --bootstrap-server=localhost:9091 --entity-name=ruban.davra-logs             --entity-type=topics --alter --add-config retention.ms=43200000,delete.retention.ms=43200001,cleanup.policy=delete,segment.bytes=104857600"
  kubectl exec -i $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh --bootstrap-server=localhost:9091 --entity-name=ruban.davra-auditLogs        --entity-type=topics --alter --add-config retention.ms=43200000,delete.retention.ms=43200001,cleanup.policy=delete,segment.bytes=104857600"
  kubectl exec -i $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh --bootstrap-server=localhost:9091 --entity-name=ruban.iotdata-preprocessor   --entity-type=topics --alter --add-config retention.ms=43200000,delete.retention.ms=43200001,cleanup.policy=delete,segment.bytes=104857600"
  touch .kafka-retention-policy-22062017
fi

kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --list --bootstrap-server localhost:9091" | grep all.user.authentications
if [ $? -ne 0 ] ; then
    kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --bootstrap-server localhost:9091 --create --partitions 1 --replication-factor="$KAFKA_REPLICATION_FACTOR" --topic all.user.authentications"
    kubectl exec -i $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh --bootstrap-server=localhost:9091 --entity-name=all.user.authentications --entity-type=topics --alter --add-config retention.ms=43200000,delete.retention.ms=43200001,cleanup.policy=delete,segment.bytes=104857600"
fi

kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --list --bootstrap-server localhost:9091" | grep heapster-metrics
if [ $? -ne 0 ] ; then
    kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --bootstrap-server localhost:9091 --create --partitions 1 --replication-factor="$KAFKA_REPLICATION_FACTOR" --topic heapster-metrics"
    kubectl exec -i $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh --bootstrap-server=localhost:9091 --entity-name=heapster-metrics --entity-type=topics --alter --add-config retention.ms=43200000,delete.retention.ms=43200001,cleanup.policy=delete,segment.bytes=104857600"
fi

kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --list --bootstrap-server localhost:9091" | grep all.actility.data.raw
if [ $? -ne 0 ] ; then
    kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --bootstrap-server localhost:9091 --create --partitions 1 --replication-factor="$KAFKA_REPLICATION_FACTOR" --topic all.actility.data.raw"
    kubectl exec -i $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh --bootstrap-server=localhost:9091 --entity-name=all.actility.data.raw --entity-type=topics --alter --add-config retention.ms=604800000,delete.retention.ms=604800001,cleanup.policy=delete,segment.bytes=104857600"
fi

kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --list --bootstrap-server localhost:9091" | grep all.davra-auditLogs
if [ $? -ne 0 ] ; then
    kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --bootstrap-server localhost:9091 --create --partitions 1 --replication-factor="$KAFKA_REPLICATION_FACTOR" --topic all.davra-auditLogs"
    kubectl exec -i $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh --bootstrap-server=localhost:9091 --entity-name=all.davra-auditLogs --entity-type=topics --alter --add-config retention.ms=604800000,delete.retention.ms=604800001,cleanup.policy=delete,segment.bytes=104857600"
fi


kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --list --bootstrap-server localhost:9091" | grep davra.fb.logs.container
if [ $? -ne 0 ] ; then
    kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --bootstrap-server localhost:9091 --create --partitions 1 --replication-factor="$KAFKA_REPLICATION_FACTOR" --topic davra.fb.logs.container"
    kubectl exec -i $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh --bootstrap-server=localhost:9091 --entity-name=davra.fb.logs.container --entity-type=topics --alter --add-config retention.ms=43200000,delete.retention.ms=43200001,cleanup.policy=delete,segment.bytes=104857600"
fi

kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --list --bootstrap-server localhost:9091" | grep ruban.davra.rulesengine.actionreports
if [ $? -ne 0 ] ; then
    kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --bootstrap-server localhost:9091 --create --partitions 1 --replication-factor="$KAFKA_REPLICATION_FACTOR" --topic ruban.davra.rulesengine.actionreports"
    kubectl exec -i $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh --bootstrap-server=localhost:9091 --entity-name=ruban.davra.rulesengine.actionreports --entity-type=topics --alter --add-config retention.ms=43200000,delete.retention.ms=43200001,cleanup.policy=delete,segment.bytes=104857600"
fi

kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --list --bootstrap-server localhost:9091" | grep all.device-updates
if [ $? -ne 0 ] ; then
    kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --bootstrap-server localhost:9091 --create --partitions 1 --replication-factor="$KAFKA_REPLICATION_FACTOR" --topic all.device-updates"
    kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --bootstrap-server localhost:9091 --create --partitions 1 --replication-factor="$KAFKA_REPLICATION_FACTOR" --topic all.twin-updates"
    kubectl exec -i $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh --bootstrap-server=localhost:9091 --entity-name=all.device-updates --entity-type=topics --alter --add-config retention.ms=86400000,delete.retention.ms=86400001,cleanup.policy=delete,segment.bytes=104857600"
    kubectl exec -i $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh --bootstrap-server=localhost:9091 --entity-name=all.twin-updates --entity-type=topics --alter --add-config retention.ms=86400000,delete.retention.ms=86400001,cleanup.policy=delete,segment.bytes=104857600"
fi
kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --list --bootstrap-server localhost:9091" | grep all.twintype-updates
if [ $? -ne 0 ] ; then
    kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --bootstrap-server localhost:9091 --create --partitions 1 --replication-factor="$KAFKA_REPLICATION_FACTOR" --topic all.twintype-updates"
    kubectl exec -i $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh --bootstrap-server=localhost:9091 --entity-name=all.twintype-updates --entity-type=topics --alter --add-config retention.ms=86400000,delete.retention.ms=86400001,cleanup.policy=delete,segment.bytes=104857600"
fi

AWT_TOPICS=`kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --list --bootstrap-server localhost:9091" | grep assets-with-twins$`
while IFS= read -r AWT_TOPIC; do
    if [ "$AWT_TOPIC" != "" ] ; then
        kubectl exec $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --describe --bootstrap-server localhost:9091 --topic $AWT_TOPIC" | grep "cleanup.policy=delete,compact" > /dev/null 2>&1
        if [ $? -ne 0 ] ; then
            echo "Updating config for topic $AWT_TOPIC"
            kubectl exec $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh  --entity-name=$AWT_TOPIC --bootstrap-server localhost:9091 --entity-type=topics --alter --add-config retention.ms=43200000,delete.retention.ms=43200001,segment.bytes=10485760,cleanup.policy=[delete,compact]" > /dev/null 2>&1
        fi
    fi
done <<< "$AWT_TOPICS"

TWIN_TOPICS=`kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --list --bootstrap-server localhost:9091" | grep -E "(.)*\.twins$"`
while IFS= read -r TWIN_TOPIC; do
    if [ "$TWIN_TOPIC" != "" ] ; then
        kubectl exec $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --describe --bootstrap-server localhost:9091 --topic $TWIN_TOPIC" | grep "cleanup.policy=delete,compact" > /dev/null 2>&1
        if [ $? -ne 0 ] ; then
            echo "Updating config for topic $TWIN_TOPIC"
            kubectl exec $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh  --entity-name=$TWIN_TOPIC --bootstrap-server localhost:9091 --entity-type=topics --alter --add-config retention.ms=43200000,delete.retention.ms=43200001,segment.bytes=10485760,cleanup.policy=[delete,compact]" > /dev/null 2>&1
        fi
    fi
done <<< "$TWIN_TOPICS"

kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --list --bootstrap-server localhost:9091" | grep all.organisations
if [ $? -ne 0 ] ; then
    kubectl exec $KAFKA_POD -i -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-topics.sh --bootstrap-server localhost:9091 --create --partitions 1 --replication-factor="$KAFKA_REPLICATION_FACTOR" --topic all.organisations"
    kubectl exec -i $KAFKA_POD -- bash -c "unset JMX_PORT; unset KAFKA_OPTS; bin/kafka-configs.sh --bootstrap-server=localhost:9091 --entity-name=all.organisations  --entity-type=topics --alter --add-config retention.ms=43200000,delete.retention.ms=43200001,cleanup.policy=delete,segment.bytes=104857600"
fi