#!/bin/bash

cd `dirname $0`

source ./utils.sh

###############
# permissions #
###############
doServiceaccount davra-api
doServiceaccount microservice-manager
doServiceaccount ruban-ms-backups

doClusterrole davra-api
doClusterrole microservice-manager
doClusterrole ruban-ms-backups

doClusterrolebinding davra-api
doClusterrolebinding microservice-manager
doClusterrolebinding ruban-ms-backups
doClusterrolebinding default

doDeployment objectstore
doService objectstore

kubectl get configmap ui-hosts > /dev/null 2>&1
if [ $? -ne 0 ] ; then
	kubectl create -f ui-hosts-configmap.yaml
fi

kubectl delete deployment aaa-service > /dev/null 2>&1 &
kubectl get service aaa-service -n default -o yaml | grep davra-api-kafka > /dev/null 2>&1 
if [ $? -ne 0 ] ; then
	kubectl delete service aaa-service > /dev/null
	kubectl create -f ruban-ms-aaa-service-service.yaml -n default
fi

doService ruban-ms-datacollector default true
kubectl delete deployment datacollector > /dev/null 2>&1 

doService ruban-ms-devicestore

doDeployment ruban-ms-iotdata-persist-service

doDeployment davra-ms-log-persist-service

doDeployment davra-ms-audit-log-persist-service

doDeployment davra-microservice-logs-persist-service


doDeployment datarouter

doDeployment payload-manager
doService payload-manager

doDeployment mote-manager
doService mote-manager

doDeployment network-manager
doService network-manager

doDeployment ruban-ms-ruban-ui
doService ruban-ms-ruban-ui

kubectl delete deployment kubernetes-metrics-persist-service > /dev/null 2>&1
kubectl delete deployment applicatonui > /dev/null 2>&1
kubectl delete service applicationui > /dev/null 2>&1 &
kubectl create -f ruban-ms-applicationui-service.yaml

# 2020-04-20: removing deployment as subsumed into davra-api
# leaving service in case any unknown remaining calls made to it.
#doDeployment ruban-ms-rules-engine
doService ruban-ms-rules-engine

doDeployment ruban-ms-backups
doService ruban-ms-backups

doDeployment ruban-ms-metric-cache

# 2020-04-10: removing deployment as subsumed into davra-api
# leaving service in case any unknown remaining calls made to it.
kubectl delete deployment ruban-ms-metric-counters-api > /dev/null 2>&1
doService ruban-ms-metric-counters-api

doConfigmap ruban-ms-device-counters-agg
doDeployment ruban-ms-device-counters-agg

doConfigmap ruban-ms-twin-counters-agg
doDeployment ruban-ms-twin-counters-agg

doDeployment davra-ms-rules-engine-metrics-agg

# 2023-02-07 removing tagstore as it is subsumed into davra-api
kubectl delete deployment ruban-ms-tagstore > /dev/null 2>&1 &
# redirecting the service name to davra-api
doService ruban-ms-tagstore default true

kubectl delete deployment ruban-ms-dataapi > /dev/null 2>&1
doService ruban-ms-dataapi default true

doPVC microservice-workspaces

kubectl get secret davra-api-token > /dev/null 2>&1
if [ $? -ne 0 ] ; then
    APITOKEN=`openssl rand -hex 64`
    sed s/TOKEN/$APITOKEN/g davra-api-secret.yaml.tpl > davra-api-secret.yaml
	kubectl create -f davra-api-secret.yaml
fi

doDeployment davra-api
kubectl get service davra-api -o yaml | grep 'name: http-alt' > /dev/null
if [ $? -ne 0 ] ; then
   kubectl delete service davra-api
fi
doService davra-api 
doHpa davra-api

echo "Sleeping for 60 seconds to allow davra-api to come up...."
sleep 60

kubectl get secret lwm2m-aes-key > /dev/null
if [ $? -ne 0 ] ; then
	openssl enc -nosalt -aes-256-cbc -k my-encryption-key -P -iter 10 > key
	kubectl create secret generic lwm2m-aes-key --from-file=key
fi

kubectl get secret gitlab > /dev/null 2>&1
if [ $? -ne 0 ] ; then
	kubectl create -f infrastructure/gitlab/gitlab-secret.yaml
fi

kubectl delete deployment ruban-ms-user-service > /dev/null 2>&1
kubectl delete service ruban-ms-user-service > /dev/null 2>&1

kubectl get secret jenkins > /dev/null  2>&1
if [ $? -ne 0 ] ; then
	kubectl create -f infrastructure/jenkins/jenkins-secret.yaml
fi

#for upgrades remove defunct rules-worker-deployment configmap
kubectl delete configmap rules-worker-deployment > /dev/null 2>&1 

kubectl get configmap data-forwarder-deployment > /dev/null 2>&1
if [ $? -eq 0 ] ; then
    kubectl delete configmap data-forwarder-deployment
fi
kubectl create configmap data-forwarder-deployment --from-file=davra-data-forwarder-deployment.json
    
##Upgrade 
kubectl describe pods | grep payloadmgr
if [ $? -eq 0 ] ; then
  echo "Delete payloadmgr is no longer required"
  kubectl delete deployment payloadmgr
fi

kubectl get deployment heapster -n kube-system > /dev/null 2>&1
if [ $? -ne 0 ] ; then
	kubectl create -f addons/heapster
else
    kubectl replace -f addons/heapster/heapster-deployment.yaml
fi

kubectl get deployment kafka-offset-monitor > /dev/null 2>&1
if [ $? -ne 0 ] ; then
	kubectl create -f addons/ruban-kafka-offset-monitor.yaml > /dev/null 2>&1 
else
	kubectl replace -f addons/ruban-kafka-offset-monitor.yaml > /dev/null 2>&1 
fi



#With the davra-api properly up and configured we can now start the microservice controllers
doDeployment ruban-ms-microservice-manager
doService ruban-ms-microservice-manager
doDeployment davra-ms-kairos-metrics-stats-service

doDeployment davra-ms-query-queue-service
doDeployment davra-ms-query-execution-service

doDeployment davra-api-tsdb
doService davra-api-tsdb
doHpa davra-api-tsdb

doDeployment davra-api-twins
doService davra-api-twins
doHpa davra-api-twins

doDeployment davra-api-kafka
doService davra-api-kafka
doHpa davra-api-kafka

doDeployment davra-api-devices
doService davra-api-devices
doHpa davra-api-devices

doDeployment davra-api-proxy
doService davra-api-proxy
doHpa davra-api-proxy

############ davra namespace ###################################
cd davra
doNamespace davra
doService davra-api davra
cd ..

############ api.connecthing proxy service for davra-api #######

doNamespace connecthing
#if the incumbent service makes no reference to api-proxy then delete and recreate it
kubectl get service -n connecthing api -o yaml | grep api-proxy
if [ $? -ne 0 ] ; then
    kubectl delete service -n connecthing api
fi
doService api connecthing

kubectl get configmap -n connecthing api-proxy-config -o yaml | grep 05032024 > /dev/null 2>&1
if [ $? -ne 0 ] ; then
	kubectl delete configmap api-proxy-config -n connecthing  > /dev/null 2>&1 
	kubectl create configmap api-proxy-config -n connecthing --from-file=default.conf=api-proxy-config
fi
doDeployment api-proxy connecthing

#AEP-3820 removing proxy process and using CNAME record instead
kubectl delete deployment -n connecthing api > /dev/null 2>&1

########### end api.connecthing proxy service for davra-api #####

#Clear out old staging microservice deployments
kubectl get deployment --all-namespaces -l "connecthing.io/microservice=true" --show-labels | tail -n+2  | grep -v davra.com/tenantId | awk '{system("kubectl delete deployment -n "$1" "$2)}'
kubectl get rs --all-namespaces -l "connecthing.io/microservice=true" --show-labels | tail -n+2  | grep -v davra.com/tenantId | awk '{system("kubectl delete rs -n "$1" "$2)}'
kubectl get service --all-namespaces -l "connecthing.io/microservice=true" --show-labels | tail -n+2  | grep -v davra.com/tenantId | awk '{system("kubectl delete service -n "$1" "$2)}'

# The process that scrapes all rules workers for performance stats
doDeployment davra-rules-engine-prometheus-scraper
