#!/bin/bash

cd `dirname $0`

source ./utils.sh

#Check prerequisite: the jq utility should be in the path
which jq > /dev/null
if [ $? -ne 0 ] ; then
    echo "The jq utility must be installed on this host and be on the PATH for the install to complete"
    exit 1
fi
echo ""

kubectl get pod --all-namespaces

DAVRA_HOST=${DAVRA_LB:-''}
if [ -z "$DAVRA_HOST" ] ; then 
    NGINX_CONTROLLER=${NGINX_SERVICE:-ingress-nginx}
    DAVRA_HOST=`kubectl get service -n ingress-nginx ${NGINX_CONTROLLER} -o=jsonpath='{.status.loadBalancer.ingress[0].hostname}'` 
    if [ $? -ne 0 ] || [ -z "$DAVRA_HOST" ] ; then
        DAVRA_HOST=`kubectl get service -n ingress-nginx ${NGINX_CONTROLLER} -o=jsonpath='{.status.loadBalancer.ingress[0].ip}'` 
    fi
    if [ $? -ne 0 ] || [ -z "$DAVRA_HOST" ] ; then
        DAVRA_HOST=127.0.0.1
    fi
fi
echo "Reaching davra system settings at host: $DAVRA_HOST"

TOKEN_NAME=`kubectl get secret -n default | grep davra-api-serviceaccount-token | awk '{print $1}'`
TOKEN=`kubectl get secret -n default $TOKEN_NAME -o yaml | grep -m 1 'token:' | awk '{print $2}' | base64 -d`

waitOnDeployment davra-api default

waitOnEndpoint "https://$DAVRA_HOST/api/v1/system/settings" $TOKEN

if  [ -n "$CASSANDRA_NODEPORTS"   -a    -n "$CASSANDRA_NODES"   ] ; then

    echo "{\"id\":\"cassandra-config\",\"nodes\":\"$CASSANDRA_NODES\",\"nodeports\":\"$CASSANDRA_NODEPORTS\"}" > cassandra-cfg.json
    echo "Sending config: "
    SETTING=`cat cassandra-cfg.json`
    rm -f cassandra-cfg.json

    curl -s -f -k -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/cassandra-config
    if [ $? -eq 0 ] ; then
        curl -X PUT  -d $SETTING -s -f -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/cassandra-config
    else
        curl -X POST -d $SETTING -s -f -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings
    fi
fi

################################################################################
# Legacy Tenant Config
RUB_DEP=`cat ruban-deployment.yaml | base64 -w 0`
echo "{\"id\":\"ruban-deployment\",\"value\":\"$RUB_DEP\"}" > ruban-deployment-setting.json
SETTING=`cat ruban-deployment-setting.json`
#rm -f ruban-deployment-setting.json

curl -s -f -k -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/ruban-deployment
if [ $? -eq 0 ] ; then
    curl -X PUT  -d $SETTING -s -f -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/ruban-deployment
else
    curl -X POST -d $SETTING -s -f -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings
fi

################################################################################
# Kafka configuration
KAFKA_REPLICATION_FACTOR=${KAFKA_REPLICATION_FACTOR:-1}
echo "{\"id\":\"kafka-configuration\",\"value\":{\"replicationFactor\":$KAFKA_REPLICATION_FACTOR}}" > kafka-configuration-setting.json
SETTING=`cat kafka-configuration-setting.json`
rm -f kafka-configuration-setting.json

curl -s -f -k -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/kafka-configuration
if [ $? -ne 0 ] ; then
    curl -X POST -d $SETTING -s -f -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings
fi

################################################################################
# rule-worker k8s deployment
RW_DEP=`cat rule-worker-deployment.json | base64 -w 0`
echo "{\"id\":\"rule-worker-deployment\",\"value\":\"$RW_DEP\"}" > rule-worker-deployment-setting.json
SETTING=`cat rule-worker-deployment-setting.json`


curl -s -f -k -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/rule-worker-deployment
if [ $? -eq 0 ] ; then
    curl -X PUT  -d $SETTING -s -f -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/rule-worker-deployment
else
    curl -X POST -d $SETTING -s -f -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings
fi

################################################################################
# rule-engine-cache k8s deployment
RW_DEP=`cat rules-engine-cache-deployment.json | base64 -w 0`
echo "{\"id\":\"rules-engine-cache-deployment\",\"value\":\"$RW_DEP\"}" > rules-engine-cache-deployment-setting.json
SETTING=`cat rules-engine-cache-deployment-setting.json`


curl -s -f -k -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/rules-engine-cache-deployment
if [ $? -eq 0 ] ; then
    curl -X PUT  -d $SETTING -s -f -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/rules-engine-cache-deployment
else
    curl -X POST -d $SETTING -s -f -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings
fi

################################################################################
# rule-engine-worker k8s deployment - V2 Rules Engine
RW_DEP=`cat rules-engine-worker-deployment.json | base64 -w 0`
echo "{\"id\":\"rules-engine-worker-deployment\",\"value\":\"$RW_DEP\"}" > rules-engine-worker-deployment-setting.json
SETTING=`cat rules-engine-worker-deployment-setting.json`


curl -s -f -k -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/rules-engine-worker-deployment
if [ $? -eq 0 ] ; then
    curl -X PUT  -d $SETTING -s -f -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/rules-engine-worker-deployment
else
    curl -X POST -d $SETTING -s -f -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings
fi

################################################################################
# davra-entity-streamer k8s deployment
DC_DEP=`cat davra-entity-streamer-deployment.json | base64 -w 0`
echo "{\"id\":\"davra-entity-streamer-deployment\",\"value\":\"$DC_DEP\"}" > davra-entity-streamer-deployment-setting.json
SETTING=`cat davra-entity-streamer-deployment-setting.json`


curl -s -f -k -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/davra-entity-streamer-deployment
if [ $? -eq 0 ] ; then
    curl -X PUT  -d $SETTING -s -f -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/davra-entity-streamer-deployment
else
    curl -X POST -d $SETTING -s -f -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings
fi

################################################################################
# rule-engine-poller k8s deployment - V2 Rules Engine Poller
RW_DEP=`cat rules-engine-poller-deployment.json | base64 -w 0`
echo "{\"id\":\"rules-engine-poller-deployment\",\"value\":\"$RW_DEP\"}" > rules-engine-poller-deployment-setting.json
SETTING=`cat rules-engine-poller-deployment-setting.json`


curl -s -f -k -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/rules-engine-poller-deployment
if [ $? -eq 0 ] ; then
    curl -X PUT  -d $SETTING -s -f -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/rules-engine-poller-deployment
else
    curl -X POST -d $SETTING -s -f -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings
fi

################################################################################
# digital-signature k8s deployment
DS_DEP=`cat davra-digital-signature-job.json | base64 -w 0`
echo "{\"id\":\"davra-digital-signature-job\",\"value\":\"$DS_DEP\"}" > davra-digital-signature-job-setting.json
SETTING=`cat davra-digital-signature-job-setting.json`


curl -s -f -k -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/davra-digital-signature-job
if [ $? -eq 0 ] ; then
    curl -X PUT  -d $SETTING -s -f -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/davra-digital-signature-job
else
    curl -X POST -d $SETTING -s -f -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings
fi

################################################################################
# davra-cron k8s deployment
DC_DEP=`cat davra-cron-deployment.json | base64 -w 0`
echo "{\"id\":\"davra-cron-deployment\",\"value\":\"$DC_DEP\"}" > davra-cron-deployment-setting.json
SETTING=`cat davra-cron-deployment-setting.json`


curl -s -f -k -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/davra-cron-deployment
if [ $? -eq 0 ] ; then
    curl -X PUT  -d $SETTING -s -f -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/davra-cron-deployment
else
    curl -X POST -d $SETTING -s -f -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings
fi

################################################################################
#Setup the default reset-password email config
curl -s -f -k -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/reset-password-config
if [ $? -ne 0 ] ; then
    echo "Setting default reset-password-config"
    CRED=`curl -f -s -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" -X POST -d '{"name": "reset-password-email-username-password", "type": "USERNAME_PASSWORD", "value":{"user":"AKIAVGQNJWRCUQJD4YHR","pass":"BO8/4lI4mAB1ik1WJKGI5GmJy6Izr7iOxymrv0EnVACk"}}' https://$DAVRA_HOST/api/v1/system/secrets 2>&1`
    if [ $? -ne 0 ] ; then
        echo $CRED
        echo "Failed to create credential for password reset $CRED"
        exit 1
    fi
    
    echo ""
    CRED_UUID=`echo $CRED | jq '.UUID' | tr -d \"`
    echo "Credential UUID: $CRED_UUID"
    sed s/###/$CRED_UUID/g default-reset-password-config > reset-password-config
    echo "Setting: "
    cat reset-password-config
    curl -i -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" -X POST --data-binary '@reset-password-config' https://$DAVRA_HOST/api/v1/system/settings
    
    if [ $? -ne 0 ] ; then
        echo "FATAL: was not able to setup password reset"
        exit 1
    fi
fi

echo ------------- QUERY_QUEUE_SETTING -----------------
QUERY_QUEUE_SETTING=`cat davra-ms-query-queue-service-system-setting.json`
curl -f -k -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/query_queue_settings
if [ $? -eq 0 ] ; then
    curl -f -i -X PUT  -d "$QUERY_QUEUE_SETTING" -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings/query_queue_settings
else
    curl -f -i -X POST -d "$QUERY_QUEUE_SETTING"  -k -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" https://$DAVRA_HOST/api/v1/system/settings
fi
echo ------------- QUERY_QUEUE_SETTING END -----------------

MONGO_URL=`kubectl get secret mongodb-connection-string -o jsonpath='{.data.mongodb_uri}' | base64 -d`
if [[ "$MONGO_URL" == *"27017/?"* ]]; then
    MONGO_URL=$(echo "$MONGO_URL" | sed "s;27017/;27017/connecthing;")
else
    MONGO_URL="$MONGO_URL/connecthing"
fi
MONGODB_POD=$(kubectl get pod -l name=mongodb | grep mongodb | awk '{print $1}')

kubectl get secret enforce-iotdata-upload-authorization-sentinel > /dev/null 2>&1
if [ $? -eq 0 ] ; then
    echo "enforceIoTDataUploadAuthorization setting has already been updated for existing tenants, skipping."
else
    kubectl exec $MONGODB_POD -- mongo $MONGO_URL --eval 'db.tenants.update({"settings.enforceIoTDataUploadAuthorization": {$exists: false}}, {$set:{"settings.enforceIoTDataUploadAuthorization":false}}, {multi:true})'> /dev/null 2>&1

    echo `date` > .iotdataauthsentinel
    kubectl create secret generic enforce-iotdata-upload-authorization-sentinel --from-file=.iotdataauthsentinel
fi

kubectl get secret enforce-legacy-pod-sentinel > /dev/null 2>&1
if [ $? -eq 0 ] ; then
    echo "runLegacyPod setting has already been updated for existing tenants, skipping."
else
    kubectl exec $MONGODB_POD -- mongo $MONGO_URL --eval 'db.tenants.update({"settings.runLegacyPod": {$exists: false}}, {$set:{"settings.runLegacyPod":true}}, {multi:true})'> /dev/null 2>&1

    echo `date` > .legacypodsentinel
    kubectl create secret generic enforce-legacy-pod-sentinel --from-file=.legacypodsentinel
fi

if [ "$CREATE_RUBAN_TENANT" = "true" ] ; then
    curl -k -X POST -d '{"id": "ruban"}' -H "content-type: application/json" -H "Authorization: Bearer $TOKEN" "https://"$DAVRA_HOST/api/v1/tenants
fi