apiVersion: v1
kind: ConfigMap
metadata:
  name: fluent-bit
  namespace: logging
  labels:
    k8s-app: fluent-bit
data:
  DAVRA_DEPLOYMENT: "ANONYMOUS_DAVRA_DEPLOYMENT"
  FLUENT_ELASTICSEARCH_HOST: "FLUENT_ELASTICSEARCH_HOST_VALUE"
  FLUENT_ELASTICSEARCH_PORT: "FLUENT_ELASTICSEARCH_PORT_VALUE"
  # Configuration files: server, input, filters and output
  # ======================================================
    # @INCLUDE input-kubernetes-json-file.conf
    # @INCLUDE filter-kubernetes-tail.conf
  fluent-bit.conf: |
    [SERVICE]
        Flush         1
        Log_Level     on
        Log_File      /fluent-bit/log/fluent-bit.log
        Daemon        off
        Parsers_File  parsers.conf
        HTTP_Server   On
        HTTP_Listen   0.0.0.0
        HTTP_Port     2020
    
     @INCLUDE input-kubernetes-systemd.conf
     @INCLUDE input-kubernetes-json-file.conf
     @INCLUDE input-kubernetes-json-file-nginx.conf
     @INCLUDE filter-kubernetes-tail.conf
     @INCLUDE filter-modify-deployment.conf
     @INCLUDE output-kafka-container.conf
     @INCLUDE output-kafka-kubelet.conf
     @INCLUDE output-kafka-nginx.conf

  input-kubernetes-json-file.conf: |
    [INPUT]
        Name              tail
        Tag               kube_tail.*
        Path              /var/log/containers/*.log
        Parser            docker
        DB                /var/log/flb_kube_tail.db
        Mem_Buf_Limit     5MB
        Skip_Long_Lines   On
        Refresh_Interval  10

  input-kubernetes-systemd.conf: |
    [INPUT]
        Name              systemd
        Tag               kube_systemd.*
        Path              /var/log/journal
        DB                /var/log/flb_kube_systemd.db
        Systemd_Filter    _SYSTEMD_UNIT=kubelet.service

  input-kubernetes-json-file-nginx.conf: |
    [INPUT]
        Name              tail
        Tag               kube_tail_nginx.*
        Path              /var/log/containers/nginx-ingress-controller*.log
        Parser            dockernginx
        DB                /var/log/flb_kube_tail_nginx.db
        Mem_Buf_Limit     5MB
        Skip_Long_Lines   On
        Refresh_Interval  10
        
  filter-kubernetes-tail.conf: |
    [FILTER]
        Name                kubernetes
        Match               kube_tail.*
        Kube_URL            https://kubernetes.default.svc:443
        Merge_Log           Off
        Merge_Log_Key       log_processed
        K8S-Logging.Parser  On
        K8S-Logging.Exclude On
        Keep_Log            On
        Kube_meta_preload_cache_dir  /tmp/k8smetacache

  filter-modify-deployment.conf: |
    [FILTER]
        Name   modify
        Match  *
        Add_if_not_present  Davra_Deployment  ${DAVRA_DEPLOYMENT}

  output-kafka-container.conf: |
    [OUTPUT]
        Name            kafka
        Match           kube_tail.*
        Brokers         kafka.default:9091
        Topics          davra.fb.logs.container

  output-kafka-kubelet.conf: |
    [OUTPUT]
        Name            kafka
        Match           kube_systemd.*
        Brokers         kafka.default:9091
        Topics          davra.fb.logs.kubelet

  output-kafka-nginx.conf: |
    [OUTPUT]
        Name            kafka
        Match           kube_tail_nginx.*
        Brokers         kafka.default:9091
        Topics          davra.fb.logs.nginx

  parsers.conf: |
    [PARSER]
        Name   nginx-json
        Format json
        Time_Key time
        Time_Format %d/%b/%Y:%H:%M:%S %z

    [PARSER]
        Name        docker
        Format      json
        Time_Key    time
        Time_Format %Y-%m-%dT%H:%M:%S.%L
        Time_Keep   On

    [PARSER]
        Name        dockernginx
        Format      json
        Time_Key    time
        Time_Format %Y-%m-%dT%H:%M:%S.%L
        Time_Keep   On
        Decode_Field_As    escaped    log
