apiVersion: v1
kind: ConfigMap
metadata:
  name: fluent-bit
  namespace: logging
  labels:
    k8s-app: fluent-bit
data:
  DAVRA_DEPLOYMENT: "ANONYMOUS_DAVRA_DEPLOYMENT"
  FLUENT_ELASTICSEARCH_HOST: "FLUENT_ELASTICSEARCH_HOST_VALUE"
  FLUENT_ELASTICSEARCH_PORT: "FLUENT_ELASTICSEARCH_PORT_VALUE"
  # Configuration files: server, input, filters and output
  # ======================================================
  fluent-bit.conf: |
    [SERVICE]
        Flush         1
        Log_Level     on
        Log_File      /fluent-bit/log/fluent-bit.log
        Daemon        off
        Parsers_File  parsers.conf
        HTTP_Server   On
        HTTP_Listen   0.0.0.0
        HTTP_Port     2020
    
    @INCLUDE input-kubernetes-json-file.conf
    @INCLUDE filter-kubernetes-tail.conf
    @INCLUDE filter-modify-deployment.conf
    @INCLUDE output-kafka-container.conf

  input-kubernetes-json-file.conf: |
    [INPUT]
        Name              tail
        Tag               kube_tail.*
        Path              /var/log/containers/*.log
        Parser            docker
        DB                /var/log/flb_kube_tail.db
        Mem_Buf_Limit     5MB
        Skip_Long_Lines   On
        Refresh_Interval  10

  filter-kubernetes-tail.conf: |
    [FILTER]
        Name                kubernetes
        Match               kube_tail.*
        Kube_URL            https://kubernetes.default.svc:443
        Merge_Log           On
        K8S-Logging.Parser  On
        Kube_meta_preload_cache_dir  /tmp/k8smetacache
        Use_Journal         Off

  filter-modify-deployment.conf: |
    [FILTER]
        Name   modify
        Match  *
        Add_if_not_present  Davra_Deployment  ${DAVRA_DEPLOYMENT}

  output-kafka-container.conf: |
    [OUTPUT]
        Name            kafka
        Match           kube_tail.*
        Brokers         kafka.default:9091
        Topics          davra.fb.logs.container

  output-stdout.conf: |
    [OUTPUT]
        Name            stdout
        Match           *

  parsers.conf: |
    [PARSER]
        Name   nginx-json
        Format json
        Time_Key time
        Time_Format %d/%b/%Y:%H:%M:%S %z

    [PARSER]
        Name        docker
        Format      json
        Time_Key    time
        Time_Format %Y-%m-%dT%H:%M:%S.%L
        Time_Keep   On

    [PARSER]
        Name        dockernginx
        Format      json
        Time_Key    time
        Time_Format %Y-%m-%dT%H:%M:%S.%L
        Time_Keep   On
        Decode_Field_As    escaped    log
