#!/bin/bash

cd `dirname $0`

which kubectl > /dev/null 2>&1
if [ $? -ne 0 ] ; then
    echo "kubectl not found on path"
    exit 1
fi

source ../../utils.sh


FLUENT_ELASTICSEARCH_HOST=${FLUENT_ELASTICSEARCH_HOST:-elasticsearch.default}
FLUENT_ELASTICSEARCH_PORT=${FLUENT_ELASTICSEARCH_PORT:-9200}
FLUENT_CONFIGMAP_TPL=${FLUENT_CONFIGMAP_TPL:-fluent-bit-configmap.yaml.tpl}

if [ "x$DAVRA_DEPLOYMENT" == "x" ] ; then
    echo "DAVRA_DEPLOYMENT environment variable not set"
    exit 1
fi

if [ "x$FLUENT_ELASTICSEARCH_HOST" == "x" ] ; then
    echo "FLUENT_ELASTICSEARCH_HOST environment variable not set - a valid elastic search deployment must be set"
    exit 1
fi

echo
echo "======================================================"
echo "| Setting up logging with the following parameters:"
echo "| FLUENT_ELASTICSEARCH_HOST: $FLUENT_ELASTICSEARCH_HOST" 
echo "| FLUENT_ELASTICSEARCH_PORT: $FLUENT_ELASTICSEARCH_PORT" 
echo "| DAVRA_DEPLOYMENT: $DAVRA_DEPLOYMENT" 
echo "======================================================"
echo

doNamespace logging

# Fluent-Bit
cd fluent-bit

sed s/FLUENT_ELASTICSEARCH_HOST_VALUE/$FLUENT_ELASTICSEARCH_HOST/g $FLUENT_CONFIGMAP_TPL | sed s/FLUENT_ELASTICSEARCH_PORT_VALUE/$FLUENT_ELASTICSEARCH_PORT/g | sed s/ANONYMOUS_DAVRA_DEPLOYMENT/$DAVRA_DEPLOYMENT/g > fluent-bit-configmap.yaml

doServiceaccount fluent-bit logging
doClusterrole fluent-bit-read
doClusterrolebinding fluent-bit-read logging

doConfigmap fluent-bit logging
doDaemonset fluent-bit logging
cd ..
