#!/bin/bash

# Create CA (you dont have to do this every time)
openssl genpkey -algorithm RSA -out ca-key -pkeyopt rsa_keygen_bits:2048
openssl req -x509 -new -key ca-key -out ca-cert -subj "/CN=davra_CA" -days 10950

#Create a truststore to used by kafka to decide whether to trust certs provided by clients
keytool -import -file ca-cert -alias CARoot -noprompt -keystore server.truststore.jks -storepass hothouse18 -keypass hothouse18

#Create key and self-signed cert for the kafka node
keytool -genkey -keyalg RSA -alias localhost -validity 10950 -dname CN=kafka,OU=Davra,O=davra.io,L=dublin,ST=Ireland,C=IE -keystore server.keystore.jks -storepass hothouse18 -keypass hothouse18

#Create a certificate request from the self-signed cert generated above
keytool -certreq -alias localhost -file cert-file -keystore server.keystore.jks -storepass hothouse18 -keypass hothouse18

#Use the CA to sign the server cert
openssl x509 -req -CA ca-cert -CAkey ca-key -in cert-file -out cert-signed -days 10950 -CAcreateserial

#Import the signed cert and the CA into the node servers keystore
keytool -import -file ca-cert -alias CARoot -noprompt -keystore server.keystore.jks -storepass hothouse18 -keypass hothouse18
keytool -import -file cert-signed -alias localhost -noprompt -keystore server.keystore.jks -storepass hothouse18 -keypass hothouse18

#Client
keytool -import -file ca-cert -alias CARoot -noprompt -keystore client.truststore.jks -storepass hothouse18 -keypass hothouse18
# private key
openssl genpkey -algorithm RSA -out client_key.pem -pkeyopt rsa_keygen_bits:2048
keytool -genkey -keyalg RSA -alias localhost -validity 10950 -dname CN=kafka,OU=Davra,O=davra.io,L=dublin,ST=Ireland,C=IE -keystore client.keystore.jks -storepass hothouse18 -keypass hothouse18

#certificate request
openssl req -new -key client_key.pem -out client.csr -subj "/CN=davra-microservice"
keytool -certreq -alias localhost -file cli-cert-file -keystore client.keystore.jks -storepass hothouse18 -keypass hothouse18

#sign the cert with the CA
openssl x509 -req -in client.csr -CA ca-cert -CAkey ca-key -CAcreateserial -out client_cert.pem -days 10950
openssl x509 -req -CA ca-cert -CAkey ca-key -in cli-cert-file -out cli-cert-signed -days 10950 -CAcreateserial

keytool -import -file ca-cert -alias CARoot -noprompt -keystore client.keystore.jks -storepass hothouse18 -keypass hothouse18
keytool -import -file cli-cert-signed -alias localhost -noprompt -keystore client.keystore.jks -storepass hothouse18 -keypass hothouse18

#tidy-up the intermediate files
rm -rf ca-cert.srl cert-file cli-cert-file cert-signed cli-cert-signed client.csr