#!/bin/bash

cd `dirname $0`

if [ $# -ne 1 ] ; then
	echo "Master host must be specified"
	exit 1
fi

export MASTER_HOST=$1
echo "MASTER_HOST: $MASTER_HOST"


export ADVERTISE_IP=$WORKER_HOST

export ETCD_ENDPOINTS="http://$MASTER_HOST:2379"
export _ETCD_ENDPOINTS="http:\/\/$MASTER_HOST:2379"
echo "ETCD_ENDPOINTS: $ETCD_ENDPOINTS"

source ./consts.sh

#TLS Assets
mkdir -p /etc/kubernetes/ssl
cp tls/ca.pem /etc/kubernetes/ssl
cp tls/apiserver.pem /etc/kubernetes/ssl
cp tls/apiserver-key.pem /etc/kubernetes/ssl
chmod 600 /etc/kubernetes/ssl/*-key.pem
chown root:root /etc/kubernetes/ssl/*-key.pem

#cloud provider config
cp openstack.conf /etc/kubernetes

#Network Config
/bin/bash nw_cfg.sh

mkdir -p /etc/kubernetes/manifests

#Kubelet
KUBELET=master-kubelet.service.tpl
sed s/K8S_VER/$K8S_CORE_VER/g $KUBELET | sed s/DNS_SERVICE_IP/$DNS_SERVICE_IP/g | sed s/ADVERTISE_IP/$MASTER_HOST/g > /etc/systemd/system/kubelet.service

#kube-proxy
sed s/K8S_VER/$K8S_CORE_VER/g master-kube-proxy.yaml.tpl > /etc/kubernetes/manifests/kube-proxy.yaml

#kubeconfig
cp master-kubeconfig.yaml /etc/kubernetes/master-kubeconfig.yaml

#kube-api
KAPI_TPL=master-kube-apiserver.yaml.tpl
sed s/ETCD_ENDPOINTS/$_ETCD_ENDPOINTS/g $KAPI_TPL | sed s/K8S_VER/$K8S_CORE_VER/g  | sed s/ADVERTISE_IP/$MASTER_HOST/g > /etc/kubernetes/manifests/kube-apiserver.yaml

#kube-controller-manager
KCM=master-kube-controller-manager.yaml.tpl
sed s/K8S_VER/$K8S_CORE_VER/g $KCM > /etc/kubernetes/manifests/kube-controller-manager.yaml

#kube-scheduler
KSCH=master-kube-scheduler.yaml.tpl
sed s/K8S_VER/$K8S_CORE_VER/g $KSCH > /etc/kubernetes/manifests/kube-scheduler.yaml

#Start services
systemctl daemon-reload

echo "Allowing etcd to come up..."
cnt=0
while [ $cnt -lt 300 ]
do
    etcdctl cluster-health > /dev/null 2>&1
    if [ $? -eq 0 ] ; then
        cnt=`expr 399`
    fi
    sleep 1
    printf "-"
    cnt=`expr $cnt + 1`
done

if [ $cnt -ne 400 ] ; then
    echo "TIMEOUT! etcd2 is not working properly, examine jounalctl -u etcd2 for more info"
    exit 1
fi  


curl -X PUT -d "value={\"Network\":\"$POD_NETWORK\",\"Backend\":{\"Type\":\"vxlan\"}}" "$ETCD_ENDPOINTS/v2/keys/coreos.com/network/config"
FLANNELD_IMAGE_TAG=`grep IMAGE_TAG /usr/lib64/systemd/system/flanneld.service | tr -d '"' | awk -F '=' '{print $3}'`
rkt fetch --trust-keys-from-https=true quay.io/coreos/flannel:$FLANNELD_IMAGE_TAG
systemctl restart flanneld
systemctl enable flanneld

systemctl restart kubelet
systemctl enable kubelet

systemctl start docker
systemctl enable docker

#kubectl
curl -O https://storage.googleapis.com/kubernetes-release/release/$K8S_VER/bin/linux/amd64/kubectl
chmod +x kubectl
export PATH=`pwd`:$PATH

#wait for api to come up
echo "Waiting for kubernetes master components to come up"
REQ="./kubectl -s localhost:8080 get namespace kube-system"
cnt=0
while [ $cnt -lt 300 ]
do
	$REQ > /dev/null 2>&1
    if [ $? -eq 0 ] ; then
        cnt=`expr 399`
    fi
    sleep 3
    printf "."
    cnt=`expr $cnt + 1`
done

if [ $cnt -ne 400 ] ; then
	echo "TIMEOUT! Kubernetes is not working properly, examine jounalctl -u kublet for more info"
	exit 1
fi
echo ""
echo "Kubernetes is up"

./kubectl -s localhost:8080 create -f kube-dashboard-rc.yaml
./kubectl -s localhost:8080 create -f kube-dashboard-svc.yaml

sed s/DNS_SERVICE_IP/$DNS_SERVICE_IP/g master-dns-addon.yaml.tpl > dns-addon.yaml
kubectl create -f dns-addon.yaml

#nginx
if [ -f /etc/nginx/conf.d/default.conf ] ; then
    docker kill nginx
    docker rm -f nginx
fi
mkdir -p /etc/nginx/conf.d
cp nginx.conf /etc/nginx/conf.d/default.conf
docker run -d --name nginx --restart=unless-stopped -v /etc/nginx/conf.d/default.conf:/etc/nginx/conf.d/default.conf -p 80:80  -p 58000:80 nginx
