#!/bin/bash

cd `dirname $0`

if [ $# -ne 2 ] ; then
	echo "Master and Worker host must be specified"
	exit 1
fi

export MASTER_HOST=$1
echo "MASTER_HOST: $MASTER_HOST"
export WORKER_HOST=$2
echo "WORKER_HOST: $WORKER_HOST"
export ADVERTISE_IP=$WORKER_HOST

export ETCD_ENDPOINTS="http://$MASTER_HOST:2379"
export _ETCD_ENDPOINTS="http:\/\/$MASTER_HOST:2379"
echo "ETCD_ENDPOINTS: $ETCD_ENDPOINTS"

source ./consts.sh

#TLS Assets
mkdir -p /etc/kubernetes/ssl
cp tls/ca.pem /etc/kubernetes/ssl
cp tls/$WORKER_HOST-worker.pem /etc/kubernetes/ssl/worker.pem
cp tls/$WORKER_HOST-worker-key.pem /etc/kubernetes/ssl/worker-key.pem
chmod 600 /etc/kubernetes/ssl/*-key.pem
chown root:root /etc/kubernetes/ssl/*-key.pem

#cloud provider config
cp openstack.conf /etc/kubernetes

#Network Config
/bin/bash nw_cfg.sh

mkdir -p /etc/kubernetes/manifests

#Kubelet
KUBELET=worker-kubelet.service.tpl
sed s/K8S_VER/$K8S_CORE_VER/g $KUBELET | sed s/ADVERTISE_IP/$ADVERTISE_IP/g | sed s/DNS_SERVICE_IP/$DNS_SERVICE_IP/g > /etc/systemd/system/kubelet.service

#kube-proxy
sed s/K8S_VER/$K8S_CORE_VER/g worker-kube-proxy.yaml.tpl | sed s/MASTER_HOST/$MASTER_HOST/g > /etc/kubernetes/manifests/kube-proxy.yaml

#worker-kubeconfig
sed s/MASTER_HOST/$MASTER_HOST/g worker-kubeconfig.yaml.tpl > /etc/kubernetes/worker-kubeconfig.yaml


#Start services
systemctl daemon-reload
curl -X PUT -d "value={\"Network\":\"$POD_NETWORK\",\"Backend\":{\"Type\":\"vxlan\"}}" "$ETCD_ENDPOINTS/v2/keys/coreos.com/network/config"
systemctl start flanneld
systemctl enable flanneld

systemctl start kubelet
systemctl enable kubelet

systemctl start docker
systemctl enable docker
