#!/bin/bash

cd `dirname $0`

mkdir tls

openssl genrsa -out tls/ca-key.pem 2048
openssl req -x509 -new -nodes -key tls/ca-key.pem -days 10000 -out tls/ca.pem -subj "/CN=kube-ca"

#API server key pairs
sed s/K8S_SERVICE_IP/$K8S_SERVICE_IP/g openssl.cnf.tpl | sed s/MASTER_HOST_PUB/$MASTER_HOST_PUB/g | sed s/MASTER_HOST/$MASTER_HOST/g > tls/openssl.cnf
openssl genrsa -out tls/apiserver-key.pem 2048
openssl req -new -key tls/apiserver-key.pem -out tls/apiserver.csr -subj "/CN=kube-apiserver" -config tls/openssl.cnf
openssl x509 -req -in tls/apiserver.csr -CA tls/ca.pem -CAkey tls/ca-key.pem -CAcreateserial -out tls/apiserver.pem -days 365 -extensions v3_req -extfile tls/openssl.cnf

#Admin key pairs
openssl genrsa -out tls/admin-key.pem 2048
openssl req -new -key tls/admin-key.pem -out tls/admin.csr -subj "/CN=kube-admin"
openssl x509 -req -in tls/admin.csr -CA tls/ca.pem -CAkey tls/ca-key.pem -CAcreateserial -out tls/admin.pem -days 365

for i in ${MINION_IPS[@]}; do
    echo "Deploying worker ${i}"
    WORKER_FQDN=${i}
    WORKER_IP=${i}
    openssl genrsa -out tls/${WORKER_FQDN}-worker-key.pem 2048
	WORKER_IP=${WORKER_IP} openssl req -new -key tls/${WORKER_FQDN}-worker-key.pem -out tls/${WORKER_FQDN}-worker.csr -subj "/CN=${WORKER_FQDN}" -config worker-openssl.cnf
	WORKER_IP=${WORKER_IP} openssl x509 -req -in tls/${WORKER_FQDN}-worker.csr -CA tls/ca.pem -CAkey tls/ca-key.pem -CAcreateserial -out tls/${WORKER_FQDN}-worker.pem -days 365 -extensions v3_req -extfile worker-openssl.cnf
done