#!/bin/bash

mkdir -p /etc/kubernetes/cni > /dev/null 2>&1 
echo 'DOCKER_OPT_BIP=""' > /etc/kubernetes/cni/docker_opts_cni.env
echo 'DOCKER_OPT_IPMASQ=""' >>  /etc/kubernetes/cni/docker_opts_cni.env

#Making docker depend on flanneld
mkdir -p /etc/systemd/system/docker.service.d/ > /dev/null 2>&1 
FLNL_CONF=/etc/systemd/system/docker.service.d/40-flannel.conf
echo "[Unit]" > $FLNL_CONF
echo "Requires=flanneld.service" >> $FLNL_CONF
echo "After=flanneld.service" >> $FLNL_CONF
echo "[Service]" >> $FLNL_CONF
echo "EnvironmentFile=/etc/kubernetes/cni/docker_opts_cni.env" >> $FLNL_CONF


if [ -f /etc/systemd/system/docker.service ] ; then
  grep 'journald' /etc/systemd/system/docker.service > /dev/null 2>&1
  if [ $? -eq 0 ] ; then
  	echo "journald logging configured"
    exit 0
  fi
fi

echo "Changing docker logging to use journald"
DOCKER_SVC_FILE=/usr/lib/systemd/system/docker.service
if [ ! -f $DOCKER_SVC_FILE ] ; then
  DOCKER_SVC_FILE=/run/systemd/system/docker.service
fi

cp $DOCKER_SVC_FILE /etc/systemd/system/
cd  /etc/systemd/system/
sed -i '/Service/a Environment="DOCKER_LOGGING=--log-driver=journald"' docker.service
sed -i  's/DOCKER_OPTS/ $DOCKER_OPTS $DOCKER_LOGGING/g' docker.service

journalctl --vacuum-time=2w
systemctl daemon-reload
systemctl stop docker.service

#loop waiting for docker to come up
printf "Waiting for docker to stop\n"
cnt=0
while [ $cnt -lt 1200 ]
do
	systemctl status docker > /dev/null 2>&1
    if [ $? -ne 0 ] ; then
        cnt=`expr 1201`
    fi
    sleep 1
    printf "."
    cnt=`expr $cnt + 1`
done

systemctl start docker.service

printf "\nWaiting for docker to start\n"
cnt=0
while [ $cnt -lt 1200 ]
do
	systemctl status docker > /dev/null 2>&1
    if [ $? -eq 0 ] ; then
        cnt=`expr 1201`
    fi
    sleep 1
    printf "+"
    cnt=`expr $cnt + 1`
done
