#!/bin/bash

#ps -ef | grep etcd | grep -v grep | grep -v repair_etcd
cd `dirname $0`

etcdctl member list | grep localhost 
ETCD_FAILING=$?
systemctl status etcd2 > /dev/null 2>&1
ETCD2_RUNNING=$?
ETCD_REPAIRED=0

TIMEOUT_IN_MINUTES=30
TIMEOUT_IN_SECONDS=`expr $TIMEOUT_IN_MINUTES \* 60`
TIMEOUT_IN_LOOPS=`expr $TIMEOUT_IN_SECONDS / 3`
NOT_TIMEOUT=`expr $TIMEOUT_IN_LOOPS + 100`


function waitForKubernetes {
	echo "Waiting for kubernetes"
	cnt=0
	while [ $cnt -lt $TIMEOUT_IN_LOOPS ]
	do
		kubectl get ns > /dev/null 2>&1
	    if [ $? -eq 0 ] ; then
	        cnt=`expr $NOT_TIMEOUT - 1`
	    fi
	    sleep 3
	    printf "-"
	    cnt=`expr $cnt + 1`
	done

	if [ $cnt -ne $NOT_TIMEOUT ] ; then
		echo "TIMEOUT! Kubernetes is not working properly, examine journalctl -u kubelet for more info"
		exit 1
	fi
}

function doRepair {
	systemctl stop etcd-member

	rm -rf /var/lib/etcd
	mkdir /var/lib/etcd
	chown -R etcd:etcd /var/lib/etcd 

	systemctl daemon-reload
	systemctl start etcd-member
	systemctl enable etcd-member
	echo "Allowing etcd to come up after repair..."
	REQ="etcdctl cluster-health"
	cnt=0
	while [ $cnt -lt 300 ]
	do
		$REQ > /dev/null 2>&1
	    if [ $? -eq 0 ] ; then
	        cnt=`expr 399`
	    fi
	    sleep 1
	    printf "-"
	    cnt=`expr $cnt + 1`
	done

	rm -f /run/systemd/system/etcd-member.service.d/98-force-new-cluster.conf
	if [ $cnt -ne 400 ] ; then
		echo "TIMEOUT! etcd2 is not working properly, examine journalctl -u etcd2 for more info"
		exit 1
	fi	
}

#Migrate data from etcd2 - etcd3. This function assumes k8s was previously installed
function migrate_to_etcd3 {
    
    #Drain the node and stop the kubelet
    NODE=`kubectl get node | tail -1 | awk '{print $1}'`
    kubectl drain $NODE --force --delete-local-data
    systemctl stop kubelet
    systemctl restart docker
    
    #Backup the etcd2 data
    mkdir -p /var/lib/etcd
    docker run -it --network host -v `pwd`:/workspace node:8 bash -c 'cd /workspace; node etcd2-backup.js'
    chown -R etcd:etcd /var/lib/etcd 

    #Stop, disable and mask etcd2    
    systemctl stop etcd2
    systemctl disable etcd2
    systemctl mask etcd2
    
    #bring up etcd 3
	systemctl daemon-reload
	systemctl start etcd-member
	systemctl enable etcd-member
	
	#Wait for etcd3 to come up
	echo "Allowing etcd to come up after migration..."
	REQ="etcdctl cluster-health"
	cnt=0
	while [ $cnt -lt 300 ]
	do
		$REQ > /dev/null 2>&1
	    if [ $? -eq 0 ] ; then
	        cnt=`expr 399`
	    fi
	    sleep 1
	    printf "-"
	    cnt=`expr $cnt + 1`
	done

	#exit on fail
	if [ $cnt -ne 400 ] ; then
		echo "TIMEOUT! etcd3 is not working properly, examine journalctl -u etcd3 for more info"
		exit 1
	fi	

    #Restore the state of etcd2 to etcd3
    docker run -it --network host -v `pwd`:/workspace node:8 bash -c 'cd /workspace ; npm install node-etcd ; node etcd2-restore.js'
    
    #Start the kubelet
    systemctl start kubelet
    waitForKubernetes
    kubectl uncordon $NODE
}

if [ $ETCD_FAILING -ne 0 ] ;  then
    echo "Repairing etcd"
  	doRepair
fi

if [ $ETCD2_RUNNING -eq 0 ] ; then
    echo "Migrating etcd2 to etcd3"
    migrate_to_etcd3
    exit 99
fi
