#!/bin/bash

if [ ! -f ca-key.pem ] ; then 
	openssl genrsa -out ca-key.pem 2048
	openssl req -x509 -new -nodes -key ca-key.pem -days 10000 -out ca.pem -subj "/CN=kube-ca"
fi

#API server key pairs
sed s/K8S_SERVICE_IP/$K8S_SERVICE_IP/g openssl.cnf.tpl | sed s/MASTER_HOST/$MASTER_HOST/g > openssl.cnf

#if env variable is set look for external IP to add to cert config
GET_EXTERNAL_IP_FROM_META=${GET_EXTERNAL_IP_FROM_META:-false}
if [ $GET_EXTERNAL_IP_FROM_META = "true" ] ; then
    EXT_IP=`curl http://169.254.169.254/latest/meta-data/public-ipv4`
    echo "IP.3 = $EXT_IP" >> openssl.cnf
fi

if [ ! -f apiserver-key.pem ] ; then
    openssl genrsa -out apiserver-key.pem 2048
fi
openssl req -new -key apiserver-key.pem -out apiserver.csr -subj "/CN=kube-apiserver" -config openssl.cnf
openssl x509 -req -in apiserver.csr -CA ca.pem -CAkey ca-key.pem -CAcreateserial -out apiserver.pem -days 3650 -extensions v3_req -extfile openssl.cnf

#Admin key pairs
if [ ! -f admin-key.pem ] ; then
    openssl genrsa -out admin-key.pem 2048
fi
openssl req -new -key admin-key.pem -out admin.csr -subj "/CN=kube-admin"
openssl x509 -req -in admin.csr -CA ca.pem -CAkey ca-key.pem -CAcreateserial -out admin.pem -days 3650

if [ -d /etc/kubernetes/ssl ] ; then
    cp -r /etc/kubernetes/ssl /etc/kubernetes/sslbackup
fi

mkdir -p /etc/kubernetes/ssl
cp ca.pem /etc/kubernetes/ssl
cp apiserver.pem /etc/kubernetes/ssl
cp apiserver-key.pem /etc/kubernetes/ssl

chmod 600 /etc/kubernetes/ssl/*-key.pem
chown root:root /etc/kubernetes/ssl/*-key.pem
