'use strict';

const { sendAlert } = require('../monitoring.lib');
const loraCheck = require('./loraCheck');

let rubanServer = 'test1.eemlive.com';
let username = 'admin';
let password = 'admin';
let roomId = 'Y2lzY29zcGFyazovL3VzL1JPT00vMGYyYTA5YzAtOTI2Yi0xMWU5LTkzZjMtNzU2OWE1YjlhZTVk';

process.argv.forEach((val) => {
  if(val.indexOf("--rubanServer=")>=0){
    rubanServer = val.substring(val.indexOf("=")+1);
  }
  else if(val.indexOf("--username=")>=0) {
    username = val.substring(val.indexOf("=")+1);
  }
  else if(val.indexOf("--password=")>=0) {
    password = val.substring(val.indexOf("=")+1);
  }
  else if(val.indexOf("--roomId=")>=0) {
    roomId = val.substring(val.indexOf("=")+1);
  }
});

async function run() {
  console.log(`Running endpoint monitor check on ${rubanServer}`);

  try {
    const loraCheckResult = await loraCheck({
      baseUrl: `https://${rubanServer}`,
      username,
      password
    });

    if (loraCheckResult.success) {
      console.log(`No issues detected on ${rubanServer}, exiting...`);
      return;
    }

    console.log(`Detected issue on ${rubanServer}, sending alert...`);

    const markdown = `${new Date()} data loss on server ${rubanServer}, iotdata uploads failing:<br/></br>${loraCheckResult.error}</br>`;
    
    console.log('Sending alert message:', markdown);

    await sendAlert({
      roomId,
      markdown
    });

    console.log('Alert message sent');
  } catch (e) {
    console.error('Unexpected error occurred', e);
  }
}

run();