#!/bin/bash

echo $@

if [ $# -ne 4 ] ; then
	echo "Not enough arguments specified, command should have the form:"
	echo "deploy-ssh-key.sh <path to current private key> <path to new public key> <path to new private key> <target server ip>"
	exit 1
fi

CURRENT_PRIV_KEY_PATH=$1
PUB_KEY_PATH=$2
NEW_PRIV_KEY_PATH=$3
VM_IP=$4

if [ -z $VM_IP ] ; then
    echo "No  VM_IP argument specified"
    exit 1
fi

if [ -z $CURRENT_PRIV_KEY_PATH ] ; then
    echo "No current private key path argument specified"
    exit 1
fi

if [ ! -f $CURRENT_PRIV_KEY_PATH ] ; then
    echo "current public key $PUB_KEY_PATH not found"
    exit 1
fi

if [ -z $PUB_KEY_PATH ] ; then
    echo "No  public key path argument specified"
    exit 1
fi

if [ ! -f $PUB_KEY_PATH ] ; then
    echo "public key $PUB_KEY_PATH not found"
    exit 1
fi

if [ -z $NEW_PRIV_KEY_PATH ] ; then
    echo "No  private key path argument specified"
    exit 1
fi

if [ ! -f $NEW_PRIV_KEY_PATH ] ; then
    echo "private key $NEW_PRIV_KEY_PATH not found"
    exit 1
fi

PUB_KEY=`cat $PUB_KEY_PATH`
USER_NAME=${USER_NAME:-ubuntu}


SSH="ssh -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no -i $CURRENT_PRIV_KEY_PATH $USER_NAME@$VM_IP"

# Overwrite the authroized_keys file on the target VM with the new public key
# This one operation invalidates the old public key and applies the new one
echo "Deploying public key for user $USER_NAME to $VM_IP: $PUB_KEY"
$SSH "echo $PUB_KEY > /home/$USER_NAME/.ssh/authorized_keys"

# exit if we didn't get a status code of 0 for the operation
if [ $? -ne 0 ] ; then
	echo "Failed to upload new public key"
	exit 1
fi

# Now test the new key pair to be sure they work on the target vm
SSH="ssh -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no -i $NEW_PRIV_KEY_PATH $USER_NAME@$VM_IP"
$SSH date

if [ $? -ne 0 ] ; then
	echo "Failed to reach $VM_IP after deploying new ssh key"
	exit 1
fi