#!/bin/bash

if [ $# -ne 2 ] ; then
    echo "FATAL: Must specify  ssh key AND server address in that order"
fi

SSH_KEY=$1
SERVER_ADDRESS=$2

if [ ! -f $SSH_KEY ] ; then
    echo "Ssh key file not found: $SSH_KEY"
    exit 1
fi

echo "Setting-up ntp on $SERVER_ADDRESS using ssh key: $SSH_KEY"

SSH="ssh -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no -i $SSH_KEY ubuntu@$SERVER_ADDRESS"

$SSH sudo apt install -y chrony
if [ $? -ne 0 ] ; then
    echo "Failed to install chrony"
    exit 1
fi


$SSH sudo cp /etc/chrony/chrony.conf /etc/chrony/chrony.conf.bak
echo "server 169.254.169.123 prefer iburst minpoll 4 maxpoll 4" > .chrony.conf.new
$SSH sudo cat /etc/chrony/chrony.conf >> .chrony.conf.new
scp -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no -i $SSH_KEY .chrony.conf.new ubuntu@$SERVER_ADDRESS:
$SSH sudo cp /home/ubuntu/.chrony.conf.new /etc/chrony/chrony.conf

$SSH sudo /etc/init.d/chrony restart

echo "Waiting for chrony service to start up"
sleep 60


$SSH chronyc sources -v

# verify settings
$SSH chronyc sources -v | grep "169.254.169.123" | grep '^\\*'
if [ $? -ne 0 ] ; then
   echo "ERROR: Verify that chrony is using the 169.254.169.123 IP address to synchronize the time. - check failed"
   exit 1
fi

#verify settings 2

$SSH chronyc tracking

$SSH chronyc tracking | grep '169.254.169.123'
if [ $? -ne 0 ] ; then
    echo "ERROR: Verify the time synchronization metrics that are reported by chrony. - check failed"
    exit 1
fi

