TOOLS
======

* `update_ip.sh` to help when moving server & updating IP address.
* `trouble.sh` to profile current state & check for errors.


# Updating IP


## Do On-Prem install as normal
   
see: https://davranetworks.atlassian.net/wiki/spaces/IARCH/pages/1520009217/Davra+on+Debian+10+Notes

Make sure everything looks grand and is working as expected

## Change IP

Move server to new network location.
Update `/etc/network/interfaces` to reflect new IP address (and any other network changes that may be needed).

Should end up looking something like:

```
# This file describes the network interfaces available on your system
# and how to activate them. For more information, see interfaces(5).

source /etc/network/interfaces.d/*

# The loopback network interface
auto lo
iface lo inet loopback

# The primary network interface
allow-hotplug enp0s3
iface enp0s3 inet static
    address 192.168.132.174
    broadcast 192.168.132.255
    netmask 255.255.255.0
    gateway 192.168.132.1
    dns-nameservers 8.8.8.8 192.168.132.1

```

### Apply network change

`sudo reboot`
       - safest, simplest way

If you really want to avoid rebooting, you can try:
```
sudo systemctl restart networking.service    
sudo ifdown <enXXX>     # for the interface name
sudo ifup -a            # bring all interfaces back up
```
In any case, if you're ssh-ing in you'll need to reconnect on the new ip anyway.


> NOTE: the script here follows this process and does most of the work for you.
> This text is kept as an explainer:

## After reboot / re login:

`ip a`
    - should reveal that the IP has been updated to the new one
     
`kubectl get pods`
    - should complain about not being able to connect to the server at the old IP

Save these as vars for use later:
```
OLD_IP="192.168.0.10"
NEW_IP="192.168.0.69"
DOMAINNAME=$(hostname --fqdn)
```

### Test IP change & network access

You might want to test in & out access at this point:

curl http://somewhere.accessible.on/the/new.network

`sudo python3 -m http.server 80` and curl/browse to http://$NEW_IP from another machine on the network.

You don't need to do this, but if things feck up later and you spend hours trawling through kube configs and swearing a lot, it might be a bit annoying to find out then that the basic net config was ths issue all along....


## Update kube config files to use the new IP

Edit the files in `/etc/kubernetes/`
In the '.conf' files, update all custer services to be something like:

```
apiVersion: v1
clusters:
- cluster:
    certificate-authority-data: ...
    server: https://192.168.0.69:6443
```
or whatever your new IP is.

And in /etc/kubernetes/manifests/kube-apiserver.yaml, update
 `   - --advertise-address=192.168.132.173 `
to become your $NEW_IP too.


For the quick & dirty find & replace, using your vars saved above:

` sudo find /etc/kubernetes/ -type f -exec sed -i "s/$OLD_IP/$NEW_IP/g" {} + `



## **VERY IMPORTANT NOTE...**

> If you used a n earlier version of the installer, you'll need to fix a mistake

In `/etc/kubernetes/manifests/kube-apiserver.yaml`

Look for the line:
`    - --service-cluster-ip-range= `

If that says 10.96... (or anything else), change it to ` 10.3.0.0/12 `

(10.96.0.0 is the kubeadm default subnet cidr if no other one is specified, but 10.3.0.0 is the Davra one. That is set at install time, but when updating & reloading the config from kube-apiserver.yaml like we're about to do, would undo that and set it back to the wrong default one.)


## Regenerate api server cert

Inspect the current one:
` sudo openssl x509 -in /etc/kubernetes/pki/apiserver.crt -text -noout `

You'll notice the old IP is included in there, we need to update this


Make backups to be safe:
```
sudo cp /etc/kubernetes/pki/apiserver.crt /tmp/
sudo cp /etc/kubernetes/pki/apiserver.key /tmp/
```

### Generate a cert signing request config
using the exitsing key & cert authority

Create a file called  `/tmp/csr.conf`:
```
[ req ]
default_bits = 2048
prompt = no
default_md = sha256
req_extensions = req_ext
distinguished_name = dn

[ dn ]
CN = $NEW_IP

[ req_ext ]
subjectAltName = @alt_names

[ alt_names ]
DNS.1 = $DOMAINNAME
DNS.2 = kubernetes
DNS.3 = kubernetes.default
DNS.4 = kubernetes.default.svc
DNS.5 = kubernetes.default.svc.cluster.local
IP.2 = 10.3.0.1
IP.1 = $NEW_IP

[ v3_ext ]
authorityKeyIdentifier=keyid,issuer:always
basicConstraints=CA:FALSE
keyUsage=keyEncipherment,dataEncipherment
extendedKeyUsage=serverAuth,clientAuth
subjectAltName=@alt_names
```

> NOTE: the CN under [ dn ]  and the IP.1 under [ alt_names ] need to be updated
> and DNS.1 = $DOMAINNAME
> ALSO: `IP.2 = 10.3.0.1` should stay as-is, that's the cluster service ip and should not be changing




### and generate the signing request with it:

`sudo openssl req -new -key /etc/kubernetes/pki/apiserver.key -out /tmp/apiserver.csr -config /tmp/csr.conf`

### and use that new csr to generate the cert:

`sudo openssl x509 -req -in /tmp/apiserver.csr -CA /etc/kubernetes/pki/ca.crt -CAkey /etc/kubernetes/pki/ca.key -CAcreateserial -out /etc/kubernetes/pki/apiserver.crt -days 10000 -extensions v3_ext -extfile /tmp/csr.conf`


> Note:
>  * /tmp/apiserver.csr & /tmp/csr.conf are the files created above, if not using the /tmp/ directory, you'll need to update those paths accordingly.
>  * /etc/kubernetes/pki/ca.crt & /etc/kubernetes/pki/ca.key are the exiting cert authority files from the original install. DO NOT EDIT THESE
>  * /etc/kubernetes/pki/apiserver.crt - is the new cert for the apiserver, generated in place of the previous one 


Run this command again to inspect the new one:

` sudo openssl x509 -in /etc/kubernetes/pki/apiserver.crt -text -noout `

...and confirm the new IP is listed.


## Do the same for ETCD peer:

Inspect the current one:

` sudo openssl x509 -in /etc/kubernetes/pki/etcd/peer.crt -text -noout `


Create another file called  `/tmp/etcd-csr.conf`:
```
[req]
default_bits = 2048
prompt = no
default_md = sha256
req_extensions = req_ext
distinguished_name = dn

[ dn ]
CN = $DOMAINNAME

[ alt_names ]
DNS.1 = $DOMAINNAME
DNS.2 = localhost
IP.1 = $NEW_IP
IP.2 = 127.0.0.1
IP.3 = 0:0:0:0:0:0:0:1

[ req_ext ]
keyUsage=keyEncipherment,dataEncipherment
extendedKeyUsage=serverAuth,clientAuth
subjectAltName=@alt_names

```

`sudo openssl req -new -key /etc/kubernetes/pki/etcd/peer.key -out /tmp/etcd-peer.csr -config /tmp/etcd-csr.conf`

... and use that new csr to generate the cert

`sudo openssl x509 -req -in /tmp/etcd-peer.csr -CA /etc/kubernetes/pki/etcd/ca.crt -CAkey /etc/kubernetes/pki/etcd/ca.key -CAcreateserial -out /etc/kubernetes/pki/etcd/peer.crt -days 10000 -extensions req_ext -extfile /tmp/etcd-csr.conf`

Confirm updates:

` sudo openssl x509 -in /etc/kubernetes/pki/etcd/peer.crt -text -noout `


## Updated certs need to be applied to the admin config

In `/etc/kubernetes/admin.conf` in the user section, there are 2 fields:
client-certificate-data & client-key-data.
These are base64 encoded version of the apiserver key & cert that we've just renewed.

In theory, you could edit these by removing the '-data' and pointing to the files:
```
    client-certificate: /etc/kubernetes/pki/apiserver.crt
    client-key: /etc/kubernetes/pki/apiserver.key
``` 

But to keep things consistent, let's just update the data:
```
API_SERVER_CERT=$(sudo cat /etc/kubernetes/pki/apiserver.crt | base64 -w0)
API_SERVER_KEY=$(sudo cat /etc/kubernetes/pki/apiserver.key | base64 -w0)

sudo sed -i "/client-certificate/c\    client-certificate-data: $API_SERVER_CERT" /etc/kubernetes/admin.conf
sudo sed -i "/client-key/c\    client-key-data: $API_SERVER_KEY" /etc/kubernetes/admin.conf
```





## Refresh files & restart service

Backup/remove the kubelet service keys:

`sudo mv /var/lib/kubelet/pki/ /tmp/kubelet-pki/`

(These will be automatically recreated and use the new ones)


Update user & root configs:
```
sudo cp /etc/kubernetes/admin.conf /root/.kube/config
sudo cp /etc/kubernetes/admin.conf /home/$USER/.kube/config
```

Reload & restart the services:

```
sudo systemctl daemon-reload
sudo systemctl stop kubelet
sudo systemctl restart docker
sudo systemctl start kubelet
```

## Kube *should* come back up at this stage

...but there's still more.

There are some config maps to be updated:

`KUBE_EDITOR="nano" kubectl -n kube-system edit cm kubeadm-config`

Find:
```
  ClusterStatus: |
    apiEndpoints:
      debian:
        advertiseAddress: 192....$OLD_IP
        bindPort: 6443
```
and update that to the new one

Similarly, in:

`KUBE_EDITOR="nano" kubectl -n kube-system edit cm kube-proxy`


```
  kubeconfig.conf: |-
    apiVersion: v1
    kind: Config
    clusters:
    - cluster:
        certificate-authority: /var/run/secrets/kubernetes.io/serviceaccount/ca.crt
        server: https:// .... $OLD_IP ... :6443
      name: default
```


> Note: you dont need to include the `KUBE_EDITOR="nano"` you can just leave that out and use vi if you're one of those people...

## Nameservers

Check your `/etc/network/interfaces` and `/etc/resolv.conf` and compare the dns nameservers.
These should match, but more importantly these should not contain localhost / 127.0.0.1 / the new IP, etc - there should be no self reference here as that woudl cause a loop issue in CoreDNS and 



## Reboot

At this point the main things should be starting to look good, but flannel is probably in a CrashLoopBackoff which is affecting other bits.

Reboot to flush everything & start clean.


## Done!

...hopefully.
After a big change like this, Kubernetes will likely take a good while to come back up fully.

`watch kubectl get pods -o wide --all-namespaces`

The kube-system pods should settle down quickly enough (aside from Heapster which usually takes longer).
kube-apiserver, coredns and etcd are the main ones to look out for, if those are not stabilising within 10 minutes, then there's probably a fundamental problem and the system is unlikely to start.
Try running the troubleshooting script and contact the core development team.

After the main kube-system pods are stable, the default namespace ones should start stabilising too.
This can happy quickly, or it can take up to half an hour, so as usual just be patient.

# Troubleshooting

Alongside the update_ip script, there's a 'trouble.sh'.
This will gather some general system info, then get the current running state of the nodes, namespaces, pods & services.
The last hour of logs are included with each pod.
This is all piped to a 'debug' directory to see full details.
Any mention of an error is also piped to the terminal, so check through that first to see if there's anything obvious.
`debug.tar.gz` can be sent for analysis to the core development team.








