#!/bin/bash

cd `dirname $0`

#root only
if [ "$(id -u)" != "0" ]; then
  echo "This script must be run as root" 1>&2
  exit 1
fi

# To get kubectl
export PATH=../../localhost:../localhost:$PATH



# loop waiting for k8s to come up
TIMEOUT_IN_MINUTES=30
TIMEOUT_IN_SECONDS=`expr $TIMEOUT_IN_MINUTES \* 60`
TIMEOUT_SLEEP_TIME=3
TIMEOUT_IN_LOOPS=`expr $TIMEOUT_IN_SECONDS / $TIMEOUT_SLEEP_TIME`
NOT_TIMEOUT=`expr $TIMEOUT_IN_LOOPS + 100`
function waitForKubernetes {
  echo "Waiting for kubernetes..."
  cnt=0
  while [ $cnt -lt $TIMEOUT_IN_LOOPS ]
  do
    kubectl get ns > /dev/null 2>&1
    if [ $? -eq 0 ] ; then
      cnt=`expr $NOT_TIMEOUT - 1`
    fi
    sleep $TIMEOUT_SLEEP_TIME
    printf "-"
    cnt=`expr $cnt + 1`
  done
  echo

  if [ $cnt -ne $NOT_TIMEOUT ] ; then
    echo "TIMEOUT! Kubernetes is not working properly, examine journalctl -u kubelet for more info"
    exit 1
  fi
}



echo "1111111111111111111111111111111111  STAGE ONE  1111111111111111111111111111111111"
echo ""
echo "Deploying infrastructure components..."

#
# Deploy the docker-registry, jenkins and gitlab
#

/bin/bash docker-registry/deploy.sh
/bin/bash jenkins/deploy.sh
/bin/bash gitlab/deploy.sh


#
# Configure GitLab
#

NODE_IP=$(kubectl get node | tail -n+2 | awk '{print $1}')

function version { echo "$@" | gawk -F. '{ printf("%03d%03d%03d\n", $1,$2,$3); }'; }

K8S_CLIENT_VER=$(kubectl version --client |  awk '{print $5}' | sed -e 's/GitVersion:"v//' | sed -e 's/",//')
if [ "$(version "$K8S_CLIENT_VER")" -le "$(version "1.7.5")" ]; then
  # For kubectl client version 1.7.5 it is column 4
  GIT_PORT_PROTO=$(kubectl get service | grep git | awk '{print $4}')
else
  # For kubectl client version 1.8.7+ it is column 5
  GIT_PORT_PROTO=$(kubectl get service | grep git | awk '{print $5}')
fi
# GIT_PORT_PROTO of format "80:31333/TCP"
GIT_PORT=`echo -e $GIT_PORT_PROTO | sed -e 's/^[0-9]*//' | sed -e 's/\/TCP$//'`


#
# Configure Jenkins Secret
#

echo ""
echo "2222222222222222222222222222222222  STAGE TWO  2222222222222222222222222222222222"
echo ""
echo "Waiting for Jenkins container to start..."

JENKINS_UP=1
while [ $JENKINS_UP -ne 0 ]
do
  kubectl get pod | grep jenkins | grep -i "1/1" > /dev/null 2>&1
  JENKINS_UP=$?
  if [ $JENKINS_UP -eq 0 ]; then
    printf "-"
    JENKINS_POD=$(kubectl get pod | grep jenkins | awk '{print $1}')
    JENKINS_PASS=$(kubectl exec -it $JENKINS_POD cat /var/jenkins_home/secrets/initialAdminPassword)
    JENKINS_UP=$?
  fi
  printf "."
  sleep 1
done

echo ""
echo "3333333333333333333333333333333333  STAGE THREE  3333333333333333333333333333333333"
echo ""
echo "Now please go to your Jenkins webpage at http://$NODE_IP/jenkins and enter the following initial password:"
echo ""
echo $JENKINS_PASS
echo ""
echo "Then click 'Continue' and 'Install Suggested Plugins' (Pipeline may fail - this can be ignored)"
echo "Once the plugin install has finished, click 'Continue'"
echo ""

echo "Next you will be asked to 'Create First Admin User' for Jenkins, fill in all details (including the email address)"
echo "Click 'Save and Finish' and then 'Start Using Jenkins'"
echo ""

read -p "Press Enter when done..."

echo ""
echo "4444444444444444444444444444444444  STAGE FOUR  4444444444444444444444444444444444"
echo ""

echo "Still on the Jenkins webpage, click on 'Manage Jenkins' (you will see warnings about installed components & notification of newer Jenkins version - please ignore these warnings)"
echo "Select 'Configure Global Security', in the section 'CSRF Protection' uncheck the 'Prevent Cross Site Request Forgery exploits' checkbox"
echo "Click 'Save'"
echo ""

read -p "Press Enter when done..."

echo ""
echo "5555555555555555555555555555555555  STAGE FIVE  5555555555555555555555555555555555"
echo ""
echo "Select 'Manage Plugins' under the 'Manage Jenkins'"
echo "Click the 'Available' tab and enter 'kuber' in the Filter box to the top right of the screen"
echo "Check the box next to 'ElasticBox Jenkins Kubernetes CI/CD Plug-in' and click 'Install without restart'"
echo ""

read -p "When the plugin has successfully installed, press Enter..."

echo ""
echo "6666666666666666666666666666666666  STAGE SIX  6666666666666666666666666666666666"
echo ""
echo "Go to 'Manage Jenkins' and select 'Configure System'"
echo "Scroll down to the first 'Cloud' of type Kubernetes cloud - In the 'Max. No. of containers' enter 300"

echo ""
echo "Scroll down further to the 'Pod Slave Configurations' - In the 'Labels' text box enter 'kubernetes-slave' (without the quotes)"
echo "Paste the text below into the 'Pod YAML definition' text area:"
echo ""
echo

echo apiVersion: "v1"
echo kind: "Pod"
echo metadata:
echo   name: "jenkins-slave"
echo   labels:
echo     name: "jenkins-slave"
echo spec:
echo     containers:
echo       - name: "jenkins-slave"
echo         image: "docker.io/davradocker/jenkins-jnlp-build-slave:0.0.1"
echo         env:
echo           - name: "JENKINS_URL"
echo             value: "http://jenkins:8080/jenkins"
echo         volumeMounts:
echo             - name: docker-socket
echo               mountPath: /var/run/docker.sock
echo               readOnly: false
echo     volumes:
echo         - name: docker-socket
echo           hostPath:
echo             path: /var/run/docker.sock
echo     securityContext:
echo       fsGroup: 10000
echo       runAsUser: 0

echo ""
echo "Finally, click 'Save' at the bottom of the page"
echo ""

read -p "Press Enter when done..."

echo ""
echo "7777777777777777777777777777777777  STAGE SEVEN  7777777777777777777777777777777777"
echo ""
echo "We now create a token for the admin user"
echo "Select 'People' then click on the admin user you just created"
echo "Click 'Configure' on the left-hand menu"
echo "In the API Token section click 'Show  API Token' & copy this token to your clipboard"
echo ""
read -p "When done, enter this Jenkins access token here: " JENKINS_TOKEN
echo ""
JENKINS_TOKEN64=`echo -n $JENKINS_TOKEN | base64`

JENKINS_USER=admin
read -p "Enter the Jenkins admin username: " JENKINS_USER
echo ""
JENKINS_USER64=`echo -n $JENKINS_USER | base64`

sed s/JENKINS_TOKEN64/$JENKINS_TOKEN64/g jenkins/jenkins-secret.yaml.tpl | sed s/JENKINS_USER64/$JENKINS_USER64/g  > jenkins/jenkins-secret.yaml
kubectl replace -f jenkins/jenkins-secret.yaml

echo ""
echo "8888888888888888888888888888888888  STAGE EIGHT  8888888888888888888888888888888888"
echo ""
echo "Waiting for GitLab container to start..."

GITLAB_UP=1
while [ $GITLAB_UP -ne 0 ]
do
  kubectl get pod | grep gitlab | grep -i "1/1" > /dev/null 2>&1
  GITLAB_UP=$?
  printf "."
  sleep 1
done

echo ""
echo "The GitLab container is now up but it may still take a while for the webserver to start."
echo "Please browse to your GitLab at http://$NODE_IP$GIT_PORT"
echo ""
read -p "Press Enter when GitLab webserver responds..."
echo ""
echo "9999999999999999999999999999999999  STAGE NINE  9999999999999999999999999999999999"
echo ""
echo "On the GitLab web page, enter a new root password and then login (as root) using that password (remembering it for later)"
echo "Once logged in, go to 'User Settings' (via icon top right) & click 'Access Tokens' tab"
echo "Enter a token name (anything will do), click all 3 scopes & create a new token - copy the new access token"
echo ""

read -p "When done, enter the GitLab access token here: " GITLAB_TOKEN
echo ""

GITLAB_TOKEN64=`echo -n $GITLAB_TOKEN | base64`
sed s/GITLAB_TOKEN64/$GITLAB_TOKEN64/g gitlab/gitlab-secret.yaml.tpl  > gitlab/gitlab-secret.yaml
kubectl replace -f gitlab/gitlab-secret.yaml

echo ""
echo "1010101010101010101010101010101010  STAGE TEN  1010101010101010101010101010101010"
echo ""
echo "We now create Jenkins credentials for the git repo"
echo ""
echo "Please go back to the Jenkins webpage, select 'Credentials' & 'System' and then click on 'Global credentials (unrestricted)'"
echo "Click 'Add Credentials'"
echo "Ensure the 'Kind' field is 'Username with password'"
echo " - Enter 'root' as the username"
echo " - Password is the password you entered for the GitLab root user above"
echo " - Enter 'rootgit' for the ID"
echo "Then click 'OK'"
echo ""

read -p "Press Enter when done..."

echo ""
echo "1111111111111111111111111111111111  STAGE ELEVEN  1111111111111111111111111111111111"
echo ""
echo "Please start a duplicate ssh session to Enable the Microservice Manager."
echo "In the new session access the Zookeeper CLI with:"
echo ""
ZK_POD=$(kubectl get pod | grep zoo | awk '{print $1}')
echo "    Davra/localhost/kubectl exec -it $ZK_POD bin/zkCli.sh"

echo ""
echo "At the '(CONNECTED)' prompt enter the following two commands:"
echo ""
echo "create /connecthing ''"
echo "create /connecthing/ruban-ms-microservice-manager {\"CONNECTHING_MICROSERVICES_ENABLED\":true} "
echo ""
echo "And then hit Ctrl-C to exit the Zookeeper container"
echo ""
echo "NOTE: Sometimes Zookeeper will throw an error at first connection, if so just retry the zkCli command from above."
echo ""

read -p "Press Enter when done..."

echo ""
echo "1212121212121212121212121212121212  STAGE TWELVE  1212121212121212121212121212121212"
echo ""
echo "Again, in the same new session, watch all pods with the following command:"
echo ""
echo "    watch Davra/localhost/kubectl get pods --all-namespaces"
echo ""

read -p "Press Enter when done..."

echo ""
echo "1313131313131313131313131313131313  STAGE THIRTEEN  1313131313131313131313131313131313"
echo ""
echo "We will now bounce Kubernetes on your a system..."
echo ""

DOCKER_REG_SVC_IP=$(kubectl get service docker-registry | tail -n 1 | awk '{print $2}')
sed s/DOCKER_REG_SVC_IP/$DOCKER_REG_SVC_IP/g daemon.json.tpl > /etc/docker/daemon.json

echo "Draining Kubernetes node..."
kubectl drain --force --delete-local-data $NODE_IP


echo "Stopping & restarting Kubernetes and Docker..."
systemctl stop kubelet > /dev/null 2>&1
systemctl stop docker

sleep 5

#systemctl daemon-reload
#systemctl enable kubelet

systemctl start docker
systemctl start kubelet

waitForKubernetes

echo "Kubernetes reconfigured - Uncordoning node"
kubectl uncordon $NODE_IP

echo ""
echo "Installation of Davra Microservices Development Infrastructure complete."
echo ""

